<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Plugina aktibatu',
'affichage' => 'Ikuspegia',
'aide_non_disponible' => 'On line delakoaren laguntza-atal hau prestatzekoa dago hizkuntza honetan.',
'auteur' => 'Egilea&nbsp;:',
'avis_acces_interdit' => 'Sarrera Debekatua',
'avis_article_modifie' => 'Adi egon,(@nom_auteur_modif@) lan honetan aritu zen orain dela (@date_diff@)minutu.',
'avis_aucun_resultat' => 'Emaitzarik ez dago.',
'avis_chemin_invalide_1' => 'Aukeratutako bideak',
'avis_chemin_invalide_2' => 'ez dirudi egokia. Itzul zaitez aurreko orrialdera eta egiazta itzazu sartutako informazioak.',
'avis_connexion_echec_1' => 'SQL zerbitzariarekiko lokarriak huts egin du.',
'avis_connexion_echec_2' => 'Itzul zaitez aurreko orrialdera eta egiazta itzazu sartutako informazioak.',
'avis_connexion_echec_3' => 'KONTUZ: Zerbitzari askotan, erabili ahal izan aurretik SQL baserako sarreraren aktibatzea eskatu behar da. Ezin baduzu konektatu, egiaztaezazu tramite hori bete duzula.',
'avis_connexion_ldap_echec_1' => 'LDAP zerbitzariarekiko lokarriak huts egin du',
'avis_connexion_ldap_echec_2' => 'Itzul zaitez aurreko orrialdera eta egiazta itzazu sartutako informazioak.',
'avis_connexion_ldap_echec_3' => 'Horren ordez, erabiltzaileak inportatzeko ez erabili LDAP euskarria.',
'avis_conseil_selection_mot_cle' => 'Talde garrantzitsua: talde honetatik gako-hitz bat aukeratzea aholkatzen da.',
'avis_deplacement_rubrique' => 'ADI EGON!. Atal honek (@contient_breves@)breve@scb@. Mugitzen baduzu, eragin ezazu baieztapen-kutxatila hau.',
'avis_destinataire_obligatoire' => 'Mezu hau igorri aurretik jasotzailea zehaztu behar duzu.',
'avis_doublon_mot_cle' => 'Un mot existe deja avec ce titre. &Ecirc;tes vous s&ucirc;r de vouloir cr&eacute;er le m&ecirc;me ?', # NEW
'avis_erreur_connexion_mysql' => 'SQL lokarri-errorea',
'avis_erreur_version_archive' => '<b>KONTUZ !

@archive@ fitxategia beste SPIP bertsio bati dagokio, instalatutakoaren desberdina.
</b>Arazo larriak edukitzeko arriskuan zaude: Zure datu-basearen suntsiketa, gunearen zenbait disfuntzio, eta abar.
Ez balidatu inportazio galdera hau.
<p>Informazio gehiago edukitzeko ikus SPIP dokumentazioa (oraindik frantsesez) .</p>', # MODIF
'avis_espace_interdit' => 'Gune helezina SPIP instalaturik dago jadanik.',
'avis_lecture_noms_bases_1' => 'Instalazio-programak ez du lortu instalaturik dauden datu-baseen izenak irakurtzea.',
'avis_lecture_noms_bases_2' => 'Bi aukera: Base erabilgarririk ez dago edo segurtasun arrazoiak direla medio baseen zerrenda-funtzioa desaktibatu egin da (zerbitzari ugaritan ohizkoa da). ',
'avis_lecture_noms_bases_3' => 'Bigarren kasuan, zure login izena duen base bat erabili ahal izatea litekeena da.',
'avis_non_acces_message' => 'Ez daukazu mezu hau irakurtzeko baimenik',
'avis_non_acces_page' => 'Ez daukazu orri honetan sartzeko baimenik',
'avis_operation_echec' => 'Eragiketak huts egin du.',
'avis_operation_impossible' => 'Ezinezko eragiketa',
'avis_probleme_archive' => '@archive@ fitxategiaren irakurketa-arazoa',
'avis_site_introuvable' => 'Gunea ez da aurkitzen',
'avis_site_syndique_probleme' => 'ADI: Leku honen sindikazioak arazoak topatzen ditu. Sistema etenik dago oraingoz.(@url_syndic@) leku horren sindikaziorako fitxategiaren helbidea egiazta ezazu, etasaia ezazu informazioen berreskurapen berri bat. ',
'avis_sites_probleme_syndication' => 'Leku hauek sindikazio-arazo bat dute',
'avis_sites_syndiques_probleme' => 'Sindikatutako leku hauek arazoak dituzte',
'avis_suppression_base' => 'KONTUZ, dataezabapena itzulezina da!',
'avis_version_mysql' => 'Zure(@version_mysql@) SQL bertsioak ez du uzten basean bertan taulen auto-konponketa.',

// B
'bouton_acces_ldap' => 'LDAP >> -rako sarrera erantsi ',
'bouton_ajouter' => 'Erantsi',
'bouton_ajouter_participant' => 'PARTEHARTZAILE BAT GEHITU:',
'bouton_annonce' => 'IRAGARKIA',
'bouton_annuler' => 'Ezeztatu',
'bouton_checkbox_envoi_message' => 'mezu bat bidaltzeko aukera',
'bouton_checkbox_indiquer_site' => 'Web toki bat derrigorrezadierazi',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'gunearen administratzaileak',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Idazlariak',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'toki publikoaren bisitariak, foro publikoetan hitz egiten dutenean.',
'bouton_checkbox_signature_unique_email' => 'Posta elektroniko bakoitzeko sinadura bana',
'bouton_checkbox_signature_unique_site' => 'sinadura bakar bat Web gune bakoitzako ',
'bouton_demande_publication' => 'Artikulu honen argitaratzea eskatu',
'bouton_desactive_tout' => 'Dena desaktibatu',
'bouton_desinstaller' => 'Desinstalatu',
'bouton_effacer_index' => 'Aurkibideak ezabatu ',
'bouton_effacer_statistiques' => 'Estatistikak ezabatu',
'bouton_effacer_tout' => 'Ezabatu DENA!',
'bouton_envoi_message_02' => 'MEZUBAT IGORRI',
'bouton_envoyer_message' => 'Behin-betiko mezua: igorri',
'bouton_forum_petition' => 'Foroa eta eskaera',
'bouton_modifier' => 'Aldatu',
'bouton_pense_bete' => 'OROIGARRI PERTSONALA',
'bouton_radio_activer_messagerie' => 'Barne mezularitza aktibatu',
'bouton_radio_activer_messagerie_interne' => 'Barne mezularitza aktibatu',
'bouton_radio_activer_petition' => 'Eskaera aktibatu',
'bouton_radio_afficher' => 'Erakutsi',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Konektaturikoerredaktoreen zerrendan agertu',
'bouton_radio_articles_futurs' => 'geroko artikulueisoilik (ez du aldatzen datu-basea).',
'bouton_radio_articles_tous' => 'artikulu guztieisalbuespenik gabe.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'artikuluguztiei, desaktibatutako foroan daudenei izan ezik.',
'bouton_radio_desactiver_messagerie' => 'Mezularitza desaktibatu',
'bouton_radio_enregistrement_obligatoire' => 'Izena ematea derrigorrezkoa da (foroanparte hartu ahal izateko, inskripzioa egin behar da posta elektronikoaren helbideaemanez).',
'bouton_radio_envoi_annonces_adresse' => 'Iragarkiak hurrengo helbideraigorri:',
'bouton_radio_envoi_liste_nouveautes' => 'Nobedadeen zerrenda igorri',
'bouton_radio_moderation_priori' => 'Aurretiaz moderatua (ekarpenak agerian egongodira lekuaren administrazio-eskubideak dituen pertsona batek onartu eta gero).',
'bouton_radio_modere_abonnement' => 'Moderatua (harpidedunentzat soilik)',
'bouton_radio_modere_posteriori' => 'gerora moderatua',
'bouton_radio_modere_priori' => 'aurretiaz moderatua',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Erredaktoreen zerrendan ez agertzea',
'bouton_radio_non_envoi_annonces_editoriales' => 'Ez igorri iragarki editorialik',
'bouton_radio_non_syndication' => 'Sindikaziorik ez',
'bouton_radio_pas_petition' => 'Eskaerarik gabe',
'bouton_radio_petition_activee' => 'Eskaera aktibaturik',
'bouton_radio_publication_immediate' => 'Mezuen bat-batekoargitaratzea (erakarpenak agerian egongo dira igorri bezain laister, gero administraziotikkendu daitezke).',
'bouton_radio_sauvegarde_compressee' => 'ecrire/data/dump.xml.gzdelakoan kopia konprimitua',
'bouton_radio_sauvegarde_non_compressee' => 'ecrire/data/dump.xml delakoan kopia ez-konprimitua',
'bouton_radio_supprimer_petition' => 'Eskaera ezabatu',
'bouton_radio_syndication' => 'Sindikazioa',
'bouton_redirection' => 'Berbideraketa',
'bouton_relancer_installation' => 'Instalazioa berriro bultzatu',
'bouton_restaurer_base' => 'Basea berreskuratu ',
'bouton_suivant' => 'Hurrengo',
'bouton_tenter_recuperation' => 'Konpontzen saiatu',
'bouton_test_proxy' => 'Proxy delakoa probatu',
'bouton_vider_cache' => 'Cachea hustu',
'bouton_voir_message' => 'Mezua ikusi bidalibaino lehen',

// C
'cache_mode_compresse' => 'Cacheko fitxategiak modu konprimituan gorde dira.',
'cache_mode_non_compresse' => 'Cacheko fitxategiak ez dira gorde modu konprimituan.',
'cache_modifiable_webmestre' => 'Parametra hauek tokiaren administratzaileak aldatzen ahal ditu.',
'calendrier_synchro' => 'Agenda-software bateragarri bat erabiltzen baduzu <b>iCal</b>, leku honen gaurkotasun-editorialarekin sinkronizatu dezakezu.',
'config_activer_champs' => 'Ondorengo eremuak aktibatu',
'config_choix_base_sup' => 'Zerbitzari honetan datu base bat zehaztu',
'config_erreur_base_sup' => 'SPIPek ez dauka sartzerik datu base erabilgarrien zerrendan',
'config_info_base_sup' => 'SPIPen bidez beste datu base batzuk kontsultatu nahi izanez gero, bere SQL zerbitzaria edo beste baten bitartez, ondorengo datu-orriarekin adierazi daitezke. Zenbait eremu hutsik uzten badira, oinarrizko datu basera konektatzeko identifikadoreak erabiliko dira.',
'config_info_base_sup_disponibles' => 'Kontsultatu daitezkeen datu base osagarriak:',
'config_info_enregistree' => 'Konfigurazio berria gordetua izan da',
'config_info_logos' => 'Web guneko elementu bakoitzak logo bat izan dezake, eta era berean &laquo;&nbsp;sagua gainean deneko logo&nbsp;&raquo; bat',
'config_info_logos_utiliser' => 'Logoak erabili',
'config_info_logos_utiliser_non' => 'Logorik ez erabili',
'config_info_logos_utiliser_survol' => 'Sagua gainean deneko logoak erabili',
'config_info_logos_utiliser_survol_non' => 'Sagua gainean deneko logorik ez erabili',
'config_info_redirection' => 'Aukera hau aktibatuta, artikulu birtualak sortu ditzakezu, hau da, beste web gune batean edo SPIPetik kanpo argitaratutako artikuluen erreferentzia soilak.',
'config_redirection' => 'Artikulu birtualak',
'config_titre_base_sup' => 'Datu base osagarri bat adierazi',
'config_titre_base_sup_choix' => 'Aukeratu datu base osagarri bat',
'connexion_ldap' => 'Konexioa :',
'copier_en_local' => 'Lokalean kopiatu',

// D
'date_mot_heures' => 'orduak',
'diff_para_ajoute' => 'Paragrafo bat erantsi egin da',
'diff_para_deplace' => 'Paragrafo murgildua',
'diff_para_supprime' => 'Paragrafo ezabatua',
'diff_texte_ajoute' => 'Testua erantsita',
'diff_texte_deplace' => 'Mugitua izan den textua',
'diff_texte_supprime' => 'Testuaezabatua',
'double_clic_inserer_doc' => 'klik bikoitzaren bidez lasterbidea testoan txertatzen ahal duzu',

// E
'email' => 'posta elektronikoa',
'email_2' => 'posta elektronikoa:',
'en_savoir_plus' => 'En savoir plus', # NEW
'entree_adresse_annuaire' => 'Urtekariaren helbidea',
'entree_adresse_email' => 'Zureposta elektronikoa',
'entree_adresse_fichier_syndication' => 'Sindikazioarako "backend"fitxeroaren helbidea.',
'entree_adresse_site' => 'Gunearen helbidea [Derrigorrezkoa]',
'entree_base_donnee_1' => 'Datu-basearen helbidea',
'entree_base_donnee_2' => '(Askotan helbide honek zure gunearekin bat dator, batzutan «localhost»arekin etabestetan, guztiz husturik geratzen da.)',
'entree_biographie' => 'Biografia labur bat, hitzgutxitan...',
'entree_breve_publiee' => 'Berri labur hau argitaratuko dugu?',
'entree_chemin_acces' => 'Sartu sarbidearen bidea:',
'entree_cle_pgp' => 'Zure PGPkodea',
'entree_contenu_rubrique' => '(Atalaren edukia, hitz gutxitan)',
'entree_description_site' => 'Gunearen deskribapena',
'entree_identifiants_connexion' => 'Zure lokarri-identifikadoreak...',
'entree_informations_connexion_ldap' => 'LDAPurtekariarekiko lokarri-informazioak bete itzazu formulario honetan. Halakoinformazioak sarearen edo sistemaren administratzaileak aditzera emango dizkizu.',
'entree_infos_perso' => 'Nor zara zu?',
'entree_interieur_rubrique' => 'Atalarenbarruan...',
'entree_liens_sites' => 'Hipertestu lotura (bisita-leku erreferentzia) ',
'entree_login' => 'Zure login-a',
'entree_login_connexion_1' => 'Zure lokarriarenidentifikatzailea',
'entree_login_connexion_2' => '(Batzutan lokarriaren login delakoaridagokio eta bestetan hutsik gelditzen da)',
'entree_login_ldap' => 'Hasierako LDAPLogin',
'entree_mot_passe' => 'Zure pasahitza',
'entree_mot_passe_1' => 'Zurelokarriaren pasahitza',
'entree_mot_passe_2' => '(Batzutan zure FTP pasahitzari dagokioeta bestetan hutsik gelditzen da)',
'entree_nom_fichier' => '@texte_compresse@fitxategiaren izenaz bete',
'entree_nom_pseudo' => 'Zure izen edo goitizena',
'entree_nom_pseudo_1' => '(Zure izen edo goitizena)',
'entree_nom_site' => 'Zuretokiaren izena',
'entree_nouveau_passe' => 'Pasahitz berria',
'entree_passe_ldap' => 'Zure pasahitza',
'entree_port_annuaire' => 'Urtekariaren atakaren zenbakia',
'entree_signature' => 'Sinadura',
'entree_texte_breve' => 'Berri laburraren testua',
'entree_titre_obligatoire' => '<b>Izenburua</b> [Derrigorrezko]<br />',
'entree_url' => 'Zure lekuaren (URL) helbidea',
'erreur_plugin_desinstalation_echouee' => 'La d&eacute;sinstallation du plugin a echou&eacute;. Vous pouvez n&eacute;anmoins le desactiver.', # NEW
'erreur_plugin_fichier_absent' => 'Fitxategia ez dago',
'erreur_plugin_fichier_def_absent' => 'Definizio fitxategia ez dago',
'erreur_plugin_nom_fonction_interdit' => 'Funtzio izena debekatuta',
'erreur_plugin_nom_manquant' => 'Plugin-aren izena eskas',
'erreur_plugin_prefix_manquant' => 'Plugin-aren izendatze eremua ez da definitua',
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; eskas definizioen fitxategian',
'erreur_plugin_version_manquant' => 'Plugin-aren bersioa eskas',

// F
'forum_info_original' => 'jatorrizkoa',

// H
'htaccess_a_simuler' => 'Avertissement: la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne s&eacute;curit&eacute;, il faut que vous modifiez cette configuration sur ce point, ou bien que les constantes @constantes@ (d&eacute;finissables dans le fichier mes_options.php) aient comme valeur des r&eacute;pertoires en dehors de @document_root@.', # NEW
'htaccess_inoperant' => 'htaccess inop&eacute;rant', # NEW

// I
'ical_info1' => 'Lekuarenbizitzarekin harremanetan egoteko dauden zenbait modu orrialde honetan aurkeztendira.',
'ical_info2' => 'Teknika guzti hauen buruzko informazio gehiago lortzeko, <a href="@spipnet@">SPIP dokumentazioa</a> kontsulta dezakezu.',
'ical_info_calendrier' => 'Bi egutegidituzu eskura. Lehena leku-planoa da, bertan argitaratutako artikulu guztiak adieraztendirelarik. Bigarrenak iragarki editorialak eta zure azken mezu pribatuak ditu: zukbakarrik ikus dezakezu gako-hitz pertsonal baten bidez, gako-hitza edozein unean aldatudaiteke zure pasahitza aldatzen baduzu.',
'ical_lien_rss_breves' => 'Guneko laburren sindikazioa',
'ical_methode_http' => 'Deskargatu',
'ical_methode_webcal' => 'Sinkronizazioa (webcal://)',
'ical_texte_js' => 'Leku honetanberriki argitaratutako artikuluak, Javascript lerro baten bidez, zurea den edozein lekutanikus ditzakezu.',
'ical_texte_prive' => 'Egutegi hau erabat pertsonala da eta leku honenekintza editorial pribatuen berri ematen du (eginkizunak, hitzordu pertsonalak,artikuluak eta proposatutako berri laburrak,..)',
'ical_texte_public' => 'Egutegi honi eskerleku honetako ekintza publikoen jarraipena egin daiteke (artikuluak eta berri laburrak)',
'ical_texte_rss' => 'Leku honen nobedadeak XML/RSS (Rich Site Summary)formatuko edozein fitxategi irakurgailuz sindikatu ditzakezu. Halaber SPIP-ak bestelekuetan argitaratutako nobedadeak irakur ditzake baldin eta leku horiek truke-formatubateragarria (sindikatutako lekuak) erabiltzen badute.',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Posta-zerrenda',
'ical_titre_rss' => '&laquo;backend&raquo; fitxategiak',
'icone_activer_cookie' => 'Korrespondentzi-“cookie”-a aktibatzea',
'icone_admin_plugin' => 'Plugin-en kudeaketa',
'icone_afficher_auteurs' => 'Egileak erakutsi',
'icone_afficher_visiteurs' => 'Bisitariakerakutsi',
'icone_arret_discussion' => 'Elkarrizketa honetan ez berriro parte hartu ',
'icone_calendrier' => 'Egutegi',
'icone_creation_groupe_mots' => 'Hitz talde berri bateratu',
'icone_creation_mots_cles' => 'Gako-hitz berri bat eratu',
'icone_creer_auteur' => 'Egile berri bat eratu eta artikulu honi elkartu',
'icone_creer_mot_cle' => 'Gako-hitz berri bat eratu eta artikuluhoni elkartu',
'icone_creer_mot_cle_breve' => 'Gako-hitz berri bat sortu eta labur huni lotu',
'icone_creer_mot_cle_rubrique' => 'Gako-hitz berri bat sortu eta atal huni lotu',
'icone_creer_mot_cle_site' => 'Gako-hitz berri bat sortu eta gune huni lotu',
'icone_creer_rubrique_2' => 'Atal berribat eratu',
'icone_ecrire_nouvel_article' => 'Atal honen berri laburrak',
'icone_envoyer_message' => 'Mezua igorri',
'icone_evolution_visites' => 'Bisiten eboluzioa @visites@ bisitak',
'icone_modif_groupe_mots' => 'Hitz talde hau aldatu',
'icone_modifier_article' => 'Artikulu hau aldatu',
'icone_modifier_breve' => 'Berri laburhau aldatu',
'icone_modifier_message' => 'Mezua aldatu',
'icone_modifier_mot' => 'Gako-hitz hori aldatu',
'icone_modifier_rubrique' => 'Atal hau aldatu',
'icone_modifier_site' => 'Leku hau aldatu',
'icone_poster_message' => 'Mezu bat igorri',
'icone_publier_breve' => 'Berri labur hau argitaratu',
'icone_referencer_nouveau_site' => 'Leku berri bat aipatu',
'icone_refuser_breve' => 'Berri labur hau ez onartu',
'icone_relancer_signataire' => 'Izenpetzaileari berreskatu',
'icone_retour' => 'Itzuli',
'icone_retour_article' => 'Artikuluraitzuli',
'icone_suivi_forum' => 'Foro publikoaren gaurkotasuna: @nb_forums@ekarpena(k)',
'icone_supprimer_cookie' => 'Korrespondentzi-“cookie”-a ezabatu',
'icone_supprimer_groupe_mots' => 'Talde hau ezabatu',
'icone_supprimer_rubrique' => 'Atal hau ezabatu',
'icone_supprimer_signature' => 'Sinadura hau ezabatu',
'icone_valider_signature' => 'Sinadura hau onartu',
'icone_voir_sites_references' => 'Aipatutako lekuak ikusi',
'icone_voir_tous_mots_cles' => 'Gako-hitz guztiak ikusi',
'image_administrer_rubrique' => 'Atal hau kudeatu ahal duzu',
'info_1_article' => 'artikulu 1',
'info_1_breve' => 'berri labur 1',
'info_1_site' => 'Toki bat',
'info_activer_cookie' => 'Egokitasun-"cookie" bat aktibatu dezakezu; horrek aukera emango dizu orrialdeakeguneratzeko, eta jendaurreko ataletik erredakziora errazki aldatzeko ere.',
'info_activer_forum_public' => 'Foru publikoak aktibatzeko, aukeratu moderazio erabat',
'info_admin_gere_rubriques' => 'Pertsona horrek honako atal hauek administratzenditu:',
'info_admin_gere_toutes_rubriques' => 'Administratzaile honek atal guztiakkudeatzen ditu.',
'info_admin_statuer_webmestre' => 'Donner &agrave; cet administrateur les droits de webmestre', # NEW
'info_admin_webmestre' => 'Cet administrateur est <b>webmestre</b>', # NEW
'info_administrateur' => 'Administratzaile',
'info_administrateur_1' => 'Administratzaile',
'info_administrateur_2' => 'gunean (kontu handiz erabili)',
'info_administrateur_site_01' => 'Administraziorako eskumenak baldin badituzu,mesedez',
'info_administrateur_site_02' => 'Egin klik lotura honetan',
'info_administrateurs' => 'Administratzaileak',
'info_administrer_rubrique' => 'Atal haukudeatu ahal duzu',
'info_adresse' => 'helbidera:',
'info_adresse_email' => 'Korreoelektroniko helbidea:',
'info_adresse_url' => 'Toki publikoaren helbidea(URL) ',
'info_afficher_visites' => 'Atal honentzako bisitak erakutsi:',
'info_affichier_visites_articles_plus_visites' => 'Hasieratik gehien irakurritakoartikuluen bisitak argitaratu :',
'info_aide_en_ligne' => 'SPIP-eko zuzeneko laguntza',
'info_ajout_image' => 'Irudiak dokumentu bezala gehitzen direnean SPIP-ekautomatikoki sartutako irudi hauen ikonoak sor ditzake. Erabilgarria izan daiteke,adibidez, galeria bat sortzeko.',
'info_ajout_participant' => 'Partehartzaile hau erantsiaizan da:',
'info_ajouter_rubrique' => 'Administratzeko beste atal bat gehitu',
'info_annonce_nouveautes' => 'Berritasunak iragarri',
'info_anterieur' => 'Lehengoa',
'info_appliquer_choix_moderation' => 'Moderazio mota hau ezarri',
'info_article' => 'artikulua',
'info_article_2' => 'artikuluak',
'info_article_a_paraitre' => 'Argitaratuakizango diren baino geroagoko data duten artikuluak',
'info_articles_02' => 'Artikuluak',
'info_articles_2' => 'Artikuluak',
'info_articles_auteur' => 'Idazlari honen artikuluak',
'info_articles_lies_mot' => 'Gako-hitz honi lotutako artikuluak',
'info_articles_trouves' => 'Aurkitutako artikuluak',
'info_articles_trouves_dans_texte' => '(Testuan)aurkitutako artikuluak',
'info_attente_validation' => 'Egiaztapenaren zain dauden zureartikuluak',
'info_aujourdhui' => 'Gaur :',
'info_auteur_message' => 'MEZUARENIDAZLEA:',
'info_auteurs' => 'Egileak',
'info_auteurs_par_tri' => '@partri@ egileak',
'info_auteurs_trouves' => 'Aurkitutako idazlariak',
'info_authentification_externe' => 'Kanpoko baimena',
'info_avertissement' => 'Abisua',
'info_barre_outils' => 'bere tresna-barrarekin ?',
'info_base_installee' => 'Zure datubasearen egitura instalatua izan da',
'info_base_restauration' => 'Basea berrezarriaizaten ari da',
'info_bloquer' => 'Blokatu',
'info_breves' => 'Berri laburren sistema erabil dezakezu',
'info_breves_03' => 'berri laburrak',
'info_breves_liees_mot' => 'Gako-hitz honi lotutako berri laburrak',
'info_breves_touvees' => 'Aurkitutako berri laburrak',
'info_breves_touvees_dans_texte' => '(Testuan) aurkitutako berri laburrak',
'info_changer_nom_groupe' => 'Talde honenizena aldatu',
'info_chapeau' => 'Idazpurua',
'info_chapeau_2' => 'Epigrafea:',
'info_chemin_acces_1' => 'Aukerak: sarbidea urtekarian',
'info_chemin_acces_2' => 'Aurrerantzean informaziorako sarbidearen bidea konfiguratu behar duzu urtekarian.Informazio hau beharrezkoa da urtekarian gordeta dauden erabiltzaileen profilakirakurtzeko.',
'info_chemin_acces_annuaire' => 'Aukerak: Sarbidea urtekarian',
'info_choix_base' => 'Hirugarren etapa:',
'info_classement_1' => '. @zerrendan@',
'info_classement_2' => '.@zerrendan@',
'info_code_acces' => 'Zure sarbide kodeak ezahaztu !',
'info_comment_lire_tableau' => 'Nola irakurri lauki hau',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Aterbetazileak ez dituenez jadanik php script-ak konprimitzen baieztatzea gomendatua da ; horretarako serbitsu hau erabiltzen ahal dezakezu&nbsp;: @testgzip@',
'info_compresseur_texte' => 'Zure sareburuak ez baditu automatikoki html orrialdeak konprimitzen erabiltzaileari igortzeko, konpresioa bortxatzen entsegatzen ahal zira deskargatutako orrien pisua ttipitzeko.<b>Kontuz</b> : teknika hunek zoinbeit sareburu zinez moteltzen ahal ditu.',
'info_compresseur_titre' => 'Optimizatu eta konprimatu',
'info_config_forums_prive' => 'Eremu pribatuan foro mota desberdinak aktibatzen ahal dituzu',
'info_config_forums_prive_admin' => 'gunearen administratzaileei erreserbatutako foroa&nbsp;:',
'info_config_forums_prive_global' => 'Foro orokor bat, idazle guziei irekia&nbsp;:',
'info_config_forums_prive_objets' => 'Foro bat artikulu, berri-labur edo erreferentzitutako gune bakoitzaren azpian&nbsp;:',
'info_config_suivi' => 'Helbide hau korreo lista bati baldin ba dagokio, hemen azpian bere bitartez tokiarenparte-hartzaileek inskripzioa egin dezaketen helbidea jar dezakezu. Helbide hau URLbat izan daiteke ( adibidez web-aren bitartez izena emateko orria), edo e-mail helbidebat gai zehatz batekin (adibidez: @adresse_suivi@?subject=subscribe):',
'info_config_suivi_explication' => 'Gune honetako posta-zerrendan harpidetza egindezakezu. Argitalpenerako proposaturiko artikuluen eta berri laburren iragarpenakjasoko dituzu posta elektronikoz.',
'info_confirmer_passe' => 'Pasahitz berria baieztatu:',
'info_conflit_edition_avis_non_sauvegarde' => '<b>Kontuz</b>, ondoko eremuak aldatuak izan dira bestalde. Beraz eremu horietan egin dituzun aldaketak ez dira grabatuak izan.',
'info_conflit_edition_differences' => 'Desberdintasunak&nbsp;:',
'info_conflit_edition_version_enregistree' => 'grabatutako bersioa&nbsp;:',
'info_conflit_edition_votre_version' => 'Zure bersioa&nbsp;:',
'info_connexion_base' => 'Bigarren etapa: basera konektatzeko saialdia ',
'info_connexion_base_donnee' => 'Zure datu-basearekin konexioa',
'info_connexion_ldap_ok' => 'LDAP konexioak funtzionatu egin du.Hurrengo etapa edo ekinaldira pasa zaitezke.', # MODIF
'info_connexion_mysql' => 'Lehenengo etapa: Zure SQL konexioa',
'info_connexion_ok' => 'Konexioa ondo dabil',
'info_contact' => 'Kontaktua',
'info_contenu_articles' => 'Artikuluen edukia',
'info_creation_mots_cles' => 'Guneko gako-hitzak sortu eta konfiguratu',
'info_creation_paragraphe' => '(Paragrafoak sortzeko, utzi lerro hutsak.)',
'info_creation_rubrique' => 'Artikuluak idatzi baino lehen Atal bat sortu behar duzu.',
'info_creation_tables' => 'Laugarren etapa: Basearen taulak sortzea',
'info_creer_base' => 'Datu base berri bat sortu:',
'info_dans_groupe' => 'Talde honetan',
'info_dans_rubrique' => 'Atal honetan...',
'info_date_publication_anterieure' => 'Lehengo argitaratze data',
'info_date_referencement' => 'Toki honen erreferentziapendata',
'info_delet_mots_cles' => 'Honako gako-hitz hau ezabatzeko eskatu duzu:@titre_mot@ (@type_mot@) Gako-hitz hori, honi lotua dago: @texte_lie@. Mesedez,berretsi zure erabakia.',
'info_derniere_etape' => 'Azken etapa : Bukatu da!',
'info_derniere_syndication' => 'Gune honen azken sindikazioa egin zen eguna:',
'info_derniers_articles_publies' => 'Zure azken artikulu argitaratuak',
'info_desactiver_forum_public' => 'Jendaurrekoforoak desaktibatu. Puntualki aktibatuak izan ahalko dira artikuluetarako, baina ezlaburretarako edo ataletarako.',
'info_desactiver_messagerie_personnelle' => 'Zuremezularitza pertsonala aktibatu edo desaktibatu dezakezu gune honetan.',
'info_descriptif' => 'Deskribapena:',
'info_desinstaller_plugin' => 'datuak ezabatzen eta plugin-a desaktibatzen ditu',
'info_discussion_cours' => 'Uneko eztabaidak',
'info_ecrire_article' => 'Artikuluak idatzi aurretik, atal bat sortu behar duzu.',
'info_email_envoi' => 'Bidalketarako posta-helbidea (aukeran)',
'info_email_envoi_txt' => 'Adierazi hemen emailak bidaltzeko erabili behar den helbidea (bestela, helbide hartzailea erabiliko da bidalketa-helbide gisa) :',
'info_email_webmestre' => 'Webmaster-aren posta elektronikoko helbidea (aukerazkoa)',
'info_entrer_code_alphabet' => 'Sar ezazu erabiliko den alfabetoaren kodea',
'info_envoi_email_automatique' => 'Mezu elektronikoen bidalketa automatikoa',
'info_envoi_forum' => 'Foroen jarraipena',
'info_envoyer_maintenant' => 'Orain bidali',
'info_erreur_restauration' => 'Lehengoratze akatsa. Fitxeroa ez dago.',
'info_etape_suivante' => 'Hurrengo etapara pasa',
'info_etape_suivante_1' => 'Hurrengoetapara pasa zaitezke',
'info_etape_suivante_2' => 'Hurrengo etapara pasa zaitezke',
'info_exportation_base' => 'basearen esportazioa @archive@-ra',
'info_facilite_suivi_activite' => 'Jarduera editorialaren jarraipena errazteko, SPIP-ekkorreo elektronikoaren bidez bidali ahal dizkio, adibidez erredaktoreen zerrenda bati,artikuluen baliaztapen eta argitarapenen eskaeren iragarkiak.',
'info_fichiers_authent' => '&laquo; .htpasswd &raquo; autentifikazio-fitxategiak',
'info_fonctionnement_forum' => 'Foroarenfuntzionamendua',
'info_forum_administrateur' => 'Administrazio taldearen foroa ',
'info_forum_interne' => 'Barruko forua',
'info_forum_ouvert' => 'Gunearen eremu pribatuan,erregistratuta dauden idazlari guztientzako foro bat zabalik dago.
 Behean, foro gehigarribat aktiba dezakezu, bakarrik administratzaileentzako erreserbatuta.',
'info_forum_statistiques' => 'Bisiten estatistikak',
'info_forums_abo_invites' => 'Zure guneak harpidetza beharrezkoa egiten dituen foroak hartzen ditu ; beraz, bisitariak gune publikoan erregistratzera gonbidatuta daude.',
'info_gauche_admin_effacer' => 'Orrialde honetan tokiaren arduradunak baino ezin dira sartu.Mantenimendu teknikoaren funtzio guztietan sartzeko aukera ematen du. Hoietakobatzuk baimentzeko prozesu bat egin behar dute eta prozesu hori egiteko web tokiari FTP-ren bidez sarrera edukitzea beharrezkoa da.', # MODIF
'info_gauche_admin_tech' => 'Orrialde honetan tokiaren arduradunak baino ezin dira sartu.Mantenimendu teknikoaren funtzio guztietan sartzeko aukera ematen du. 
Horietako batzuk baimentzeko prozesu bat egin behar dute eta prozesu hori egiteko web tokiari FTP-ren bidez sarrera edukitzea beharrezkoa da.', # MODIF
'info_gauche_admin_vider' => 'Orrialde honetan tokiaren arduradunak baino ezin dira sartu.Mantenimendu teknikoaren funtzio guztietan sartzeko aukera ematen du. Hoietakobatzuk baimentzeko prozesu bat egin behar dute eta prozesu hori egiteko web tokiariFTP-ren bidez sarrera edukitzea beharrezkoa da.', # MODIF
'info_gauche_auteurs' => 'Guneko autore guztiak ageri dira hemen. 
Ikonoaren koloreak autore bakoitzaren egoera adierazten du (idazlaria = berdea; administratzailea = horia).',
'info_gauche_auteurs_exterieurs' => 'Kanpoko autoreak, gunean sartzeko baimenik ezdutenak, ikono urdin batez adierazten dira; ezabatuak izan direnak, berriz, paperontzibatez.',
'info_gauche_messagerie' => 'Mezularitzak idazlarien artean mezuak trukatzen,abisuak kontserbatzen (zure erabilera pertsonalarentzat), edo eremu pribatuko orri nagusian iragarpenak jartzen (administratzailea bazara) uzten dizu.',
'info_gauche_numero_auteur' => 'IDAZLEA ',
'info_gauche_numero_breve' => 'Berri laburra',
'info_gauche_statistiques_referers' => 'Orri honetan referers-en zerrenda dago, hau da, zure web-gunera eramaten dituztenloturak dauzkaten tokien zerrenda, bakarrik atzo eta gaurko; zerrenda honek egunerozerora jartzen da.',
'info_gauche_suivi_forum' => 'Foroak jarraitzeko orrialdea zureguneko kudeaketa-tresna bat da (eta ez eztabaida edo idazketa-eremu bat). Artikulu honen foro publikoko kontribuzio guztiak bistaratzen ditu eta kontribuzio hauek administratzen uzten dizu.',
'info_gauche_suivi_forum_2' => 'Foroak jarraitzeko orrialdea zureguneko kudeaketa-tresna bat da (eta ez eztabaida edo idazketa-eremu bat). Guneko foroetako kontribuzio guztiak bistaratzen ditu, bai gune publikokoak bai eremu pribatukoak eta kontribuzio hauek administratzen uzten dizu.',
'info_gauche_visiteurs_enregistres' => 'Hemen guneko eremu publikoan erregistratutako bisitariak aurkituko dituzu (foroak aurretiko harpidetzaz).',
'info_generation_miniatures_images' => 'Irudien miniatura-sorkuntza',
'info_gerer_trad' => 'Itzulpen-estekak kudeatu?',
'info_groupe_important' => 'Talde garrantzitsua',
'info_hebergeur_desactiver_envoi_email' => 'Ostapen zuzkitzaile batzuek mail-bidalketa automatikoa desaktibatzen dute bere zerbitzarietatik.
Kasu honetan, SPIP-eko hurrengo funtzinalitateak ez dute funtzionatuko.',
'info_hier' => 'atzo:',
'info_historique' => 'Berrikuspenak :',
'info_historique_activer' => 'Berrikuspenen jarraipena aktibatu',
'info_historique_affiche' => 'Bertsio hau bistaratu',
'info_historique_comparaison' => 'konparazioa',
'info_historique_desactiver' => 'Berrikuspenen jarraipena desaktibatu',
'info_historique_lien' => 'Aldaketen zerrenda erakutsi',
'info_historique_texte' => 'Berrikuspenen jarraipenak artikulu baten edukiari egindako aldaketa guztien historia gordetzen eta geroko bertsioen arteko desberdintasunak bistaratzen uzten du.',
'info_historique_titre' => 'Berrikuspenen jarraipena',
'info_identification_publique' => 'Zurenortasun publikoa...',
'info_image_process' => 'Mesedez aukeratu biñetak egitekomodurik onena dagokion irudian klikatuz.',
'info_image_process2' => '<b>N.B.</b> Ez bada irudirik agertzen, orduan zure gunea ostatatzen duen zerbitzaria ez dago konfiguratuta tresna horiek erabiltzeko. Funtzio horiek erabili nahi badituzu, arduradun teknikoarekin kontaktatu eta &laquo;GD&raquo; edo &laquo;Imagick&raquo; luzapenak eskatu.',
'info_images_auto' => 'Automatikoki kalkulatutako irudiak',
'info_informations_personnelles' => 'Bosgarren etapa : Datu pertsonalak',
'info_inscription_automatique' => 'Pertsona berrien izen-emate automatikoa',
'info_jeu_caractere' => 'Guneko karaktere-jokoa',
'info_jours' => 'egunak',
'info_laisser_champs_vides' => 'Aukera hauek hutsik utzi)',
'info_langues' => 'Gunearen hizkuntzak',
'info_ldap_ok' => 'LDAP autentikazioa instalatuta dago.',
'info_lien_hypertexte' => 'Hipertestu lotura:',
'info_liens_syndiques_1' => 'esteka sindikatuak',
'info_liens_syndiques_2' => 'balidazioaren zain daude.',
'info_liens_syndiques_3' => 'foroak',
'info_liens_syndiques_4' => 'daude',
'info_liens_syndiques_5' => 'foroa',
'info_liens_syndiques_6' => 'dago',
'info_liens_syndiques_7' => 'balidazioaren zain',
'info_liste_redacteurs_connectes' => 'Konektatuak dauden erredaktoreen zerrenda',
'info_login_existant' => 'Login hori dagoeneko existitzen da.',
'info_login_trop_court' => 'Login hori laburregia da',
'info_logos' => 'Logoak',
'info_maximum' => 'gehienez:',
'info_meme_rubrique' => 'Atal berean',
'info_message' => 'Mezua',
'info_message_efface' => 'Mezua ezabatu da',
'info_message_en_redaction' => 'Idaztekobidean dauden zure mezuak',
'info_message_technique' => 'Mezu teknikoa',
'info_messagerie_interne' => 'Barne mezularitza',
'info_mise_a_niveau_base' => 'Zure SQL basearen eguneratzea',
'info_mise_a_niveau_base_2' => '{{Kontuz!}} Lehendikgune honetan aurkitzen zen SPIP fitxategien {lehenagoko} bertsio bat instalatuduzu: zure datu-basea galdua izateko arriskuan dago eta zure guneak ez dugehiago funtzionatuko.{{SPIP fitxategiak berrinstalatu.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Foro publikoenfuntzionamendua',
'info_modifier_auteur' => 'Egilea aldatu :',
'info_modifier_breve' => 'Berri laburra aldatu',
'info_modifier_mot' => 'Gako-hitza aldatu :',
'info_modifier_rubrique' => 'Gaia aldatu :',
'info_modifier_titre' => 'Aldatu :@titre@',
'info_mon_site_spip' => 'Nire SPIP gunea',
'info_mot_sans_groupe' => '(Talderik gabeko hitzak...)',
'info_moteur_recherche' => 'Barneratutako bilaketa motorra',
'info_mots_cles' => 'Gako-hitzak',
'info_mots_cles_association' => 'Talde honetako gako-hitzak erlazionatuta egon daitezke :',
'info_moyenne' => 'ertaina :',
'info_multi_articles' => 'Artikuluetan hizkuntza menu-a aktibatu?',
'info_multi_cet_article' => 'Artikuluhonen hizkuntza:',
'info_multi_langues_choisies' => 'Jarraian aukeratu zure tokiarenidazleek erabiltzeko baimena izango dituzten hizkuntzak. Tokian dagoeneko erabiltzendiren hizkuntzak (zerrendaren hasieran) ezin dira desaktibatu. ',
'info_multi_rubriques' => 'Ataletan hizkuntza menu-a aktibatu?',
'info_multi_secteurs' => '>... erroan dauden atalentzat bakarrik ?',
'info_nom' => 'Izena',
'info_nom_destinataire' => 'Hartzailearen izena',
'info_nom_site' => 'Zure gunearen izena',
'info_nom_site_2' => 'Gunearen izena [Nahitaezkoa]',
'info_nombre_articles' => '@nb_articles@ artikulu,',
'info_nombre_breves' => '@nb_breves@ labur,',
'info_nombre_partcipants' => 'Debatean parte-hartzaile...',
'info_nombre_rubriques' => '@nb_rubriques@ atal,',
'info_nombre_sites' => '@nb_sites@ gune,',
'info_non_deplacer' => 'Ez murgildu...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP-ek guneko azken berrien abisuak bidaltzen ahal ditu erregularki (artikulu eta berri labur argitaratu berriak).',
'info_non_envoi_liste_nouveautes' => 'Ez bidali nobedadeen zerrenda',
'info_non_modifiable' => 'ezin da aldatu',
'info_non_suppression_mot_cle' => 'Ez dutgako-hitz hau ezabatu nahi',
'info_notes' => 'Oharrak',
'info_nouveaux_message' => 'Mezu berriak',
'info_nouvel_article' => 'Artikulu berria',
'info_nouvelle_traduction' => 'Itzulpen berria:',
'info_numero_article' => 'Artikulua:',
'info_obligatoire_02' => '[Nahitaezkoa]',
'info_option_accepter_visiteurs' => 'Gune publikoko bisitarien inskripzioa onartu',
'info_option_email' => 'Guneko bisitari batek artikulu batekin erlazionatutako mezu berri bat bidaltzen duenean foroan, artikuluaren idazleak mezu honetaz abisatuakizan ahal dira e-mailez. Aukera hau erabili nahi duzu ?',
'info_option_faire_suivre' => 'Foroetako mezuak artikuluen idazleei jarraituak izateaegin',
'info_option_ne_pas_accepter_visiteurs' => 'Bisitarien inskripzioa ezetsi',
'info_option_ne_pas_faire_suivre' => 'Ez bidali foroetako mezuak',
'info_options_avancees' => 'Aukera aurreratuak',
'info_ortho_activer' => 'Zuzentzaile ortografikoa aktibatu',
'info_ortho_desactiver' => 'Zuzentzaile ortografikoa desaktibatu',
'info_ou' => 'edo...',
'info_oui_suppression_mot_cle' => 'Gako-hitz hauezabatu nahi dut',
'info_page_interdite' => 'Orri debekatua',
'info_par_nom' => 'izenez',
'info_par_nombre_article' => '(artikulu kopuruaren arabera)',
'info_par_statut' => 'egoeraren arabera',
'info_par_tri' => '\'(par @tri@)\'',
'info_pas_de_forum' => 'fororik ez',
'info_passe_trop_court' => 'Pasahitz laburregia.',
'info_passes_identiques' => 'Pasahitzak ezberdinak dira',
'info_pense_bete_ancien' => 'Zure ohartarapen zaharrak', # MODIF
'info_plus_cinq_car' => '5 karaktere baino gehiago',
'info_plus_cinq_car_2' => '(5 karaktere baino gehiago)',
'info_plus_trois_car' => '(3karaktere baino gehiago)',
'info_popularite' => 'Arrakasta: @popularite@ Bisitak:@visites@',
'info_popularite_2' => 'Gunearen arrakasta edo onarpena:',
'info_popularite_3' => 'Arrakasta: @popularite@ Bisitak: @visites@',
'info_popularite_4' => 'Arrakasta: @popularite@ Bisitak: @visites@',
'info_post_scriptum' => 'Post scriptum',
'info_post_scriptum_2' => 'Post scriptum:',
'info_pour' => '-rako',
'info_preview_admin' => 'Administratzaileek baino ez dute tokiaaurreikusteko baimena.',
'info_preview_comite' => 'Idazlari guztiek tokia aurreikusten ahal dute',
'info_preview_desactive' => 'Aurreikuspena guztiz desaktibatuta dago',
'info_preview_texte' => 'Gunea artikulu eta berri labur guztiak (gutxienez&laquo; proposatua &raquo; statusa dutenak) argitaratuta egon balira bezala aurreikustea posible da. Posibilitate hau administratzaileentzat bakarrik, idazlari guztientzat, edo inorentzat egon behar da zabalik?',
'info_principaux_correspondants' => 'Zure korrespontsal printzipalak',
'info_procedez_par_etape' => 'etapaz etapa jokatu',
'info_procedure_maj_version' => 'Eguneratzeko prozedura bete egin behar da datu-basea SPIP-en bertsio berrira moldatzeko.',
'info_proxy_ok' => 'Proxy-aren proba lortua',
'info_ps' => 'P.S',
'info_publier' => 'Argitaratu',
'info_publies' => 'Zure artikuluargitaratuak',
'info_question_accepter_visiteurs' => 'Zure tokiaren egituretan gunepribaturako baimenik gabeko bisitanteen errejistroa aurreikusia baldin badago, aukerahau aktibatu egin beharko duzu:',
'info_question_activer_compactage_css' => 'CSS Estilo-orrien trinkotzea aktibatu al nahi duzu ?',
'info_question_activer_compactage_js' => 'Javascript script-en trinkotzea aktibatu al nahi duzu ?',
'info_question_activer_compresseur' => 'HTTP korrontearen konprimitzea aktibatu al nahi duzu ?',
'info_question_gerer_statistiques' => 'Zure tokiakbisiten estatistikak kudeatzea nahi duzu?',
'info_question_inscription_nouveaux_redacteurs' => 'Gune publikotik idazlari berrien inskripzioak onartzen dituzu ?
Onartzen badituzu, bisitariak inprimaki automatizatu batetik harpidetu ahal izango dira eta orduan eremu pribatuan sartuko dira beren artikuluak proposatzeko.

Inskribatzean, erabiltzaileek mezu elektroniko automatiko bat jasotzen dute gune pribaturako sarbide-kodeak emanez.

Ostapen zuzkitzaile batzuek mail-bidalketa desaktibatzen dute bere zerbitzarietatik : kasu honetan, inskripzio automatikoa ezinezkoa da.', # MODIF
'info_question_mots_cles' => 'Zure gunean gako-hitzakerabili nahi dituzu?',
'info_question_proposer_site' => 'Nork proposatu ahal ditu gune erreferentziatuak ?',
'info_question_utilisation_moteur_recherche' => 'SPIP-ean integratutako bilatzailea erabili nahi duzu ?
(desaktibapenak sistemaren funtzionamendua bizkortzen du.)',
'info_question_vignettes_referer' => 'Estatistikak begiratzean, bisiten jatorrien guneen aurrebista ikusten ahal duzu',
'info_question_vignettes_referer_non' => 'Bisiten jatorrien guneen kapturak ez erakutsi',
'info_question_vignettes_referer_oui' => 'Bisiten jatorrien guneen kapturak erakutsi',
'info_question_visiteur_ajout_document_forum' => 'Si vous souhaitez autoriser les visiteurs &agrave; joindre des documents (images, sons...) &agrave; leurs messages de forum, indiquer ci-dessous la liste des extensions de documents autoris&eacute;s pour les forums (ex: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Le cas &#233;ch&#233;ant, indiquer ci-dessous la liste des extensions de documents autoris&#233;s pour les forums (ex: gif, jpg, png, mp3).', # MODIF
'info_qui_attribue_mot_cle' => 'Talde honetako hitzak hurrengoagatik esleituak izan daitzeke :',
'info_racine_site' => 'Gunearen erroa',
'info_recharger_page' => 'Mesedez orrialde hau berriz kargatu minutu batzuk barru.',
'info_recherche_auteur_a_affiner' => 'Emaitza gehiegi "@cherche_auteur@"-rako ; mesedez bilaketa doitu.',
'info_recherche_auteur_ok' => 'Egile asko aurkituak"@cherche_auteur@"-rako:',
'info_recherche_auteur_zero' => 'Emaitzarik ez &laquo;@cherche_auteur@ &raquo;-rako.',
'info_recommencer' => 'Mesedez berrabiarazi.',
'info_redacteur_1' => 'Idazlaria',
'info_redacteur_2' => 'eremu pribaturako sarbidea duen(gomendatua)',
'info_redacteurs' => 'Idazleak',
'info_redaction_en_cours' => 'Idaztekobidean',
'info_redirection' => 'Birbidirekzioa',
'info_referencer_doc_distant' => 'Dokumentu bat interneten erreferentziatu&nbsp;:',
'info_refuses' => 'Zure artikulu ezetsiak',
'info_reglage_ldap' => 'Aukerak : LDAP inportazioaren konfigurazioa',
'info_renvoi_article' => 'Birbidirekzioa. Artikulu hau orrialdera itzultzen da:',
'info_reserve_admin' => 'Helbide hauAdministrazio taldeak bakarrik aldatu ahal du',
'info_restauration_sauvegarde' => '@archive@ babeskopiaren leheneratzea',
'info_restauration_sauvegarde_insert' => '@archive@ datu-basean txertatu',
'info_restreindre_rubrique' => 'Kudeaketa atalera mugatu :',
'info_resultat_recherche' => 'Bilaketaren emaitzak:',
'info_rubriques' => 'Atalak',
'info_rubriques_02' => 'atalak',
'info_rubriques_liees_mot' => 'Gako-hitz honi lotutako atalak',
'info_rubriques_trouvees' => 'Aukitutako atalak',
'info_rubriques_trouvees_dans_texte' => 'Aurkitutako atalak (testuan)',
'info_sans_titre' => 'Titulurik gabe',
'info_sauvegarde' => 'Babeskopia',
'info_sauvegarde_articles' => 'Artikuluen ziurtasun kopia egin',
'info_sauvegarde_articles_sites_ref' => 'Gune erreferentziatuetako artikuluak gorde',
'info_sauvegarde_auteurs' => 'Egileak gorde',
'info_sauvegarde_breves' => 'Berri laburrak gorde',
'info_sauvegarde_documents' => 'Dokumentuak gorde',
'info_sauvegarde_echouee' => 'Babeskopiak huts egiten badu (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Foroak gorde',
'info_sauvegarde_groupe_mots' => 'Hitz-taldeak gorde',
'info_sauvegarde_messages' => 'Mezuak gorde',
'info_sauvegarde_mots_cles' => 'Gako-hitzak gorde',
'info_sauvegarde_petitions' => 'Eskaerak gorde',
'info_sauvegarde_refers' => 'Erreferituak gorde',
'info_sauvegarde_reussi_01' => 'Baliozko babeskopia.',
'info_sauvegarde_reussi_02' => 'Basea ecrire/data/@archive@-ean gorde da. Ahal zara',
'info_sauvegarde_reussi_03' => 'kudeaketara itzuli',
'info_sauvegarde_reussi_04' => 'zure gunearen.',
'info_sauvegarde_rubrique_reussi' => '@titre@ gaieko mahaiak @archive@-ean gordetuak izan dira.',
'info_sauvegarde_rubriques' => 'Atalak gorde',
'info_sauvegarde_signatures' => 'Eskaera-sinadurak gorde',
'info_sauvegarde_sites_references' => 'Gune erreferientziatuak gorde',
'info_sauvegarde_type_documents' => 'Dokumentu-motak gorde',
'info_sauvegarde_visites' => 'Bisitak gorde',
'info_selection_chemin_acces' => 'Ondoren urtekarian sartzeko bidea hautatu :',
'info_selection_un_seul_mot_cle' => 'Bakoitzean gako-hitz bat bakarrik hauta daiteketalde honetan.',
'info_signatures' => 'sinadurak',
'info_site' => 'Tokia',
'info_site_2' => 'tokia :',
'info_site_min' => 'tokia',
'info_site_propose' => 'Toki proposatua',
'info_site_reference_2' => 'Toki erreferientziatua',
'info_site_syndique' => 'Gune hau sindikatuta dago...',
'info_site_valider' => 'Balidatzeko guneak',
'info_site_web' => 'WEB GUNEA :',
'info_sites' => 'guneak',
'info_sites_lies_mot' => 'Gako-hitz honi lotutako gune erreferientziatuak',
'info_sites_proxy' => 'Proxy bat erabili',
'info_sites_refuses' => 'Ezetsitako guneak',
'info_sites_trouves' => 'Aurkitutako guneak',
'info_sites_trouves_dans_texte' => 'Aurkitutako guneak(testuan)',
'info_sous_titre' => 'Azpititulua :',
'info_statut_administrateur' => 'Administratzailea',
'info_statut_auteur' => 'Egile honen estatusa:',
'info_statut_auteur_a_confirmer' => 'Izen-ematea baieztatzekoa',
'info_statut_auteur_autre' => 'Beste egoera&nbsp;:',
'info_statut_efface' => 'Ezabatuta',
'info_statut_redacteur' => 'Idazlea',
'info_statut_site_1' => 'Gune hau dago :',
'info_statut_site_2' => 'Argitaratuta',
'info_statut_site_3' => 'Proposatuta',
'info_statut_site_4' => 'Zakarrontzian',
'info_statut_utilisateurs_1' => 'Inportatutako erabiltzaileen estatus lehenetsia',
'info_statut_utilisateurs_2' => 'LDAP urtekarian dauden pertsonei emandako estatusa aukeratu lehen aldiz konektatzen direnean. Ondoren balio hau aldatu ahal izango duzu idazle bakoitzarentzat kasuz kasu.',
'info_suivi_activite' => 'argitaratze-jardueraren jarraipena',
'info_supprimer_mot' => 'hitz hau kendu',
'info_surtitre' => 'Aurreizenburua',
'info_syndication_integrale_1' => 'Zure guneak sindikazio fitxategiak (ikus &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).',
'info_syndication_integrale_2' => 'Artikuluak beren osotasunean igorri nahi al dituzu, edo zonait ehuneko karakteretako bilduma bat zabaldu nahi duzu ?',
'info_table_prefix' => 'Datu-mahaien aurrizkia aldatzen ahal duzu (beharrezkoa da gune anitz ezarri nahi direlarik datu-base berdinean). Aurrizki hori miniskuloz idazten da, azenturik edo espazioarik gabe.',
'info_taille_maximale_images' => 'Tratzen ahal dituen irudien neurri handienak probatuko ditu.<br />Handiago diren irudiak ez dira ttipituak izanen.',
'info_taille_maximale_vignette' => 'Sistemak sortutako bineten tamaina maximoa :',
'info_terminer_installation' => 'Orain instalazio estandarraren prozedura amaitzen ahal duzu.',
'info_texte' => 'Testua',
'info_texte_explicatif' => 'Testu esplikatiboa',
'info_texte_long' => '(testua luzea da : beraz, balidazio ondoren berriz elkartuko diren zati askotan agertzen da.)',
'info_texte_message' => 'Zure mezuaren testua :',
'info_texte_message_02' => 'Mezuaren testua',
'info_titre' => 'Titulua :',
'info_titre_mot_cle' => 'Gako-hitzaren izena edo titulua',
'info_total' => 'guztira :',
'info_tous_articles_en_redaction' => 'Artikulu guztiak idazteko bidean',
'info_tous_articles_presents' => 'Argitaratutako artikulu guztiak eremu honetan',
'info_tous_articles_refuses' => 'Tous les articles refus&eacute;s', # NEW
'info_tous_les' => 'guztiak :',
'info_tous_redacteurs' => 'Idazlari guztientzako abisuak',
'info_tout_site' => 'Gune guztia',
'info_tout_site2' => 'Artikulua ez da hizkuntza honetara itzuli.',
'info_tout_site3' => 'Artikulua hizkuntza honetara itzuli da, baina ondoren erreferentzia-artikuluari aldaketak egin zaizkio. Itzulpena eguneratu behar da.',
'info_tout_site4' => 'Artikulua hizkuntza honetara itzuli da, eta itzulpena eguneratuta dago.',
'info_tout_site5' => 'Artikulu originala.',
'info_tout_site6' => '<b>Erne :</b> bakarrik artikulu originalak bistaratzen dira.
Itzulpenak originalari asoziatuta daude, bere egoera adierazten duten kolore batean :',
'info_travail_colaboratif' => 'Artikuluei buruzko lan kolaboratiboa',
'info_un_article' => 'artikulu bat,',
'info_un_mot' => 'Hitz bakar bat aldi berean',
'info_un_site' => 'gune bat,',
'info_une_breve' => 'berri labur bat,',
'info_une_rubrique' => 'atal bat,',
'info_une_rubrique_02' => 'atal bat',
'info_url' => 'URL ',
'info_url_site' => 'Gunearen URL-a',
'info_urlref' => 'Hipertestu lotura:',
'info_utilisation_spip' => 'Lagundutakoargitaratze sistema erabiltzen has zaitezke...',
'info_visites_par_mois' => 'Bisitak hilabeteko :',
'info_visites_plus_populaires' => 'Bisitak bistaratu artikulu hedatuenengatik eta argitaratutako azken artikuluengatik :',
'info_visiteur_1' => 'Bisitaria',
'info_visiteur_2' => 'gune publikoaren',
'info_visiteurs' => 'Bisitariak',
'info_visiteurs_02' => 'Gune publikoaren bisitariak',
'install_adresse_base_hebergeur' => 'Aterbetzaileak emandako datu-basearen helbidea',
'install_base_ok' => '@base@ basea ezagutua izan da',
'install_echec_annonce' => 'Instalazioak seguraski huts eginen du, edo martxan izanen ez den gune bat sortuko du...',
'install_extension_mbstring' => 'SPIP ez da ibilki hunekin&nbsp;:',
'install_extension_php_obligatoire' => 'SPIPek beharesten du php luzapena&nbsp;:',
'install_login_base_hebergeur' => 'Aterbetzaileak emandako konexion login-a',
'install_nom_base_hebergeur' => 'Aterbetzaileak emandako bassearen izena&nbsp;:',
'install_pas_table' => 'Une honetan mahaik gabeko baseak',
'install_pass_base_hebergeur' => 'Aterbetzaileak emandako konexiorako pasahitza',
'install_php_version' => 'PHP @version@ bertsioa ez da aski (guttienez = @minimum@)',
'install_select_langue' => 'Hizkuntza bat aukeratu eta &laquo; hurrengoa &raquo; botoian klikatu instalazio-prozedura hasteko.',
'install_select_type_db' => 'Zehaztu datu-base mota&nbsp;:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL', # NEW
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Aterbetzaileak emandako datu-base zerbitzaria',
'install_table_prefix_hebergeur' => 'Aterbetzaileak emandako mahaiaren aurrizkia&nbsp;:',
'install_tables_base' => 'Baseko mahaiak',
'install_types_db_connus' => 'SPIPek <b>MySQL</b> (erabiliena), <b>PostgreSQL</b> eta <b>SQLite</b> badakizka erabiltzen.',
'install_types_db_connus_avertissement' => 'Kontuz&nbsp;: plugin zonbaitzu MySQL-ekin baizik ibiltzen dira',
'intem_redacteur' => 'idazlaria',
'intitule_licence' => 'Lizenzia',
'item_accepter_inscriptions' => 'Inskripzioak onartu',
'item_activer_forum_administrateur' => 'Administrazio-taldearen foroa aktibatu.',
'item_activer_messages_avertissement' => 'Ohartarazpen mezuak aktibatu',
'item_administrateur_2' => 'administratzailea',
'item_afficher_calendrier' => 'Egutegianerakutsi',
'item_ajout_mots_cles' => 'Baimendu gako-hitzak foroetan ',
'item_autoriser_documents_joints' => 'Artikuluei erantsitako dokumentuak baimendu',
'item_autoriser_documents_joints_rubriques' => 'Ataletako artikuluak baimendu',
'item_autoriser_selectionner_date_en_ligne' => 'dokumentu bakotxaren data aldatzea baimendu',
'item_autoriser_syndication_integrale' => 'Artikuluen osotasuna zabaldu sindikazio fitxategietan',
'item_bloquer_liens_syndiques' => 'Onartzeko prozesuan dauden sindikatutako loturakblokeatu',
'item_breve_refusee' => 'Berri laburra arbuiaturik',
'item_breve_validee' => 'Berri laburra arbuiaturik',
'item_choix_administrateurs' => 'administratzaileak',
'item_choix_generation_miniature' => 'Irudien miniaturak automatikoki sortu',
'item_choix_non_generation_miniature' => 'Ez sortu miniaturarik',
'item_choix_redacteurs' => 'erredaktoreak',
'item_choix_visiteurs' => 'lekuarenbisitariak',
'item_compresseur' => 'Konpresioa aktibatu',
'item_config_forums_prive_global' => 'Idazleen foroa aktibatu',
'item_config_forums_prive_objets' => 'Foro hauek aktibatu',
'item_creer_fichiers_authent' => '".htpasswd" fitxategiak sortu',
'item_desactiver_forum_administrateur' => 'Administrazio-foroa desaktibatu',
'item_gerer_annuaire_site_web' => 'Web lekuen urtekari bat kudeatu',
'item_gerer_statistiques' => 'Estatistikak kudeatu',
'item_limiter_recherche' => 'Lekuhonetan mugatu ikerketa',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Mezutegia eta agenda aktibatu',
'item_mots_cles_association_articles' => 'artikuluekin',
'item_mots_cles_association_breves' => 'berri laburrekin',
'item_mots_cles_association_rubriques' => 'atalekin',
'item_mots_cles_association_sites' => 'aipatutako edo sindikatutako lekuekin',
'item_non' => 'Ez',
'item_non_accepter_inscriptions' => 'Ez onartu inskripziorik',
'item_non_activer_messages_avertissement' => 'Ohar mezurik gabe',
'item_non_afficher_calendrier' => 'Ez erakutsi egutegian',
'item_non_ajout_mots_cles' => 'Foroetan gako-hitzak erabiltzea galarazi',
'item_non_autoriser_documents_joints' => 'Artikuluetan dokumentuak sartzea galarazi',
'item_non_autoriser_documents_joints_rubriques' => 'Ataletan dokumentuak sartzeagalarazi',
'item_non_autoriser_selectionner_date_en_ligne' => 'Dokumentuen data da gunean noiz gehituak izan diren data',
'item_non_autoriser_syndication_integrale' => 'Bilduma bat baizik zabaldu',
'item_non_bloquer_liens_syndiques' => 'Ez blokeatu sindikazio-loturak',
'item_non_compresseur' => 'Konprimatzea desaktibatu',
'item_non_config_forums_prive_global' => 'idazleen foroa desaktibatu',
'item_non_config_forums_prive_objets' => 'Foro hauek desaktibatu',
'item_non_creer_fichiers_authent' => 'Ez sortu fitxategi horiek',
'item_non_gerer_annuaire_site_web' => 'Web lekuen urtekaria desaktibatu',
'item_non_gerer_statistiques' => 'Ez kudeatu estatistikarik',
'item_non_limiter_recherche' => 'Aipatutako lekuen edukian ikertu',
'item_non_messagerie_agenda' => 'Mezutegia eta agenda desaktibatu',
'item_non_publier_articles' => 'Artikuluak adierazitako argitaratze data baino lehen ezargitaratu',
'item_non_utiliser_breves' => 'Ez erabili berri laburrak',
'item_non_utiliser_config_groupe_mots_cles' => 'Ez erabili gako-hitz taldeenkonfigurazio zehatza',
'item_non_utiliser_moteur_recherche' => 'Ez erabili motorra',
'item_non_utiliser_mots_cles' => 'Ez erabili gako-hitzak',
'item_non_utiliser_syndication' => 'Ez erabili sindikazio automatikoa',
'item_nouvel_auteur' => 'Egile berria',
'item_nouvelle_breve' => 'Berri labur berria',
'item_nouvelle_rubrique' => 'Atal berria',
'item_oui' => 'Bai',
'item_publier_articles' => 'Artikuluak argitaratu argitaratze-eguna kontuan izan gabe ',
'item_reponse_article' => 'Artikuluari erantzuna',
'item_utiliser_breves' => 'Berri laburrak erabili',
'item_utiliser_config_groupe_mots_cles' => 'Gako-hitz taldeen konfigurazio zehatzaerabili',
'item_utiliser_moteur_recherche' => 'Bilaketa-motorra erabili',
'item_utiliser_mots_cles' => 'Gako-hitzak erabili',
'item_utiliser_syndication' => 'Sindikazio automatikoa erabili',
'item_visiteur' => 'bisitaria',

// J
'jour_non_connu_nc' => 'e.e.',

// L
'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
'lien_ajout_destinataire' => 'Jasotzaile hau erantsi',
'lien_ajouter_auteur' => 'Egile hau erantsi',
'lien_ajouter_participant' => 'Parte-hartzaile bat erantsi',
'lien_email' => 'posta elektronikoa',
'lien_forum_public' => 'Artikulu honen foroa kudeatu',
'lien_mise_a_jour_syndication' => 'Orain gaurkotu',
'lien_nom_site' => 'Lekuaren izena',
'lien_nouvelle_recuperation' => 'Datuak berreskuratzen berriro saiatu',
'lien_reponse_article' => 'Artikuluari erantzuna',
'lien_reponse_breve' => 'Berri laburrarierantzuna',
'lien_reponse_breve_2' => 'Atalari erantzuna',
'lien_reponse_rubrique' => 'Atalari erantzuna',
'lien_reponse_site_reference' => 'Aipatutako lekuari erantzuna',
'lien_retirer_auteur' => 'Egile hau baztertu',
'lien_retrait_particpant' => 'Parte-hartzailehau baztertu',
'lien_site' => 'lekua',
'lien_supprimer_rubrique' => 'Atal hau kendu',
'lien_tout_deplier' => 'Hedatu dena',
'lien_tout_replier' => 'Bildu dena',
'lien_tout_supprimer' => 'Dena kendu',
'lien_trier_nom' => 'Izenagatik sailkatu',
'lien_trier_nombre_articles' => 'Artikuluen izenagatik sailkatu',
'lien_trier_statut' => 'Estatusagatik sailkatu',
'lien_voir_en_ligne' => 'LINEAN IKUSI :',
'logo_article' => 'Artikuluaren logotipoa...',
'logo_auteur' => 'EGILEAREN LOGOA',
'logo_breve' => 'BERRI LABURRAREN LOGOA',
'logo_mot_cle' => 'GAKO-HITZAREN LOGOA',
'logo_rubrique' => 'ATALAREN LOGOA',
'logo_site' => 'GUNEAREN LOGOA',
'logo_standard_rubrique' => 'ATALEN LOGO ESTANDARRA',
'logo_survol' => 'LOGOA BEGIRATUAGATIK',

// M
'menu_aide_installation_choix_base' => 'Zure basearen aukera',
'module_fichier_langue' => 'Hizkuntza-fitxategia',
'module_raccourci' => 'Lasterbidea',
'module_texte_affiche' => 'Testu bistaratua',
'module_texte_explicatif' => 'Hurrengo lasterbideak txerta ditzakezu zure gune publikoko eskeletoetan. Automatiko kihizkuntza-fitxategi bat existitzen denentzako hizkuntza desberdinetara itzuliko dira.',
'module_texte_traduction' => '« @module@ » hizkuntza artxiboaikusgai dago hemen:',
'mois_non_connu' => 'ezezagun',

// N
'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW

// O
'onglet_contenu' => 'Edukia',
'onglet_declarer_une_autre_base' => 'Beste base bat deklaratu',
'onglet_discuter' => 'Solastu',
'onglet_documents' => 'Dokumentuak',
'onglet_interactivite' => 'Interaktibitatea',
'onglet_proprietes' => 'Proprietateak',
'onglet_repartition_actuelle' => 'gaur egun',
'onglet_sous_rubriques' => 'Azpi-eremuak',

// P
'page_pas_proxy' => 'Orri hau ez da proxy-tik pasa behar',
'pas_de_proxy_pour' => 'Beharrez, zehaztu zein tresna edo eremuentzat proxy hau ez den aplikatu behar (adibidez&nbsp;:@exemple@)',
'plugin_charge_paquet' => '@name@ paketearen kargatzea',
'plugin_charger' => 'T&#233;l&#233;charger', # NEW
'plugin_erreur_charger' => 'errorea&nbsp;: @zip@ kargatzea ezinezkoa da',
'plugin_erreur_droit1' => '<code>@dest@</code> direktorioan ezin da idatzi.',
'plugin_erreur_droit2' => 'Direktorio hunen eskubideak baiezta itzazu (sortuz beharrez), edo fitxategiak FTParen bidez instala itzazu.',
'plugin_erreur_zip' => 'pclzip errorea&nbsp;: @status@ errorea',
'plugin_etat_developpement' => 'garapenean',
'plugin_etat_experimental' => 'experimentala',
'plugin_etat_stable' => 'egonkorra',
'plugin_etat_test' => 'proban',
'plugin_impossible_activer' => '@plugin@ plugin-a ezin da aktibatu',
'plugin_info_automatique1' => 'Plugin-en instalazio automatikoa onartu nahi al baduzu, otoi&nbsp;:',
'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l\'installation automatique de cette librairie, veuillez&nbsp;:', # NEW
'plugin_info_automatique2' => '<code>@rep@</code> direktorio bat sortu;',
'plugin_info_automatique3' => 'Direktorio hunetan zerbitzariak idazteko eskubidea baduela segurta ezazu.',
'plugin_info_automatique_creer' => 'gunearen erroan sortzekoa.',
'plugin_info_automatique_exemples' => 'adibideak&nbsp;:',
'plugin_info_automatique_ftp' => 'Plugin batzu FTPren bidez instalatzen ahal dituzu <tt>@rep@</tt> direktorioan',
'plugin_info_automatique_lib' => 'Plugin zonbaitek <code>lib/</code> direktorioan fitxategi batzu telekargatzea eskatzen dute.Beharrez direktorio hori sortu behar duzu, gunearen sustraian.',
'plugin_info_automatique_liste' => 'Zure pluginen zerrenda:',
'plugin_info_automatique_liste_officielle' => 'Plugin ofizialak',
'plugin_info_automatique_liste_update' => 'Zerrendak gaurkotu',
'plugin_info_automatique_ou' => 'edo...',
'plugin_info_automatique_select' => 'Plugin bat aukera ezazu beherago : SPIPek deskargatuko du eta <code>@rep@</code> direktorioan instalatuko du&nbsp;; plugin hau jadanik existitzen bada, gaurkotua izanen da.',
'plugin_info_extension_1' => 'Les extensions ci-dessous sont charg&#233;es et activ&#233;es dans le r&#233;pertoire @extensions@.', # NEW
'plugin_info_extension_2' => 'Elles ne sont pas d&#233;sactivables.', # NEW
'plugin_info_telecharger' => '@url@ helbidetik deskargatu beharra, eta @rep@ direktorioan instalatzekoa',
'plugin_librairies_installees' => 'Instalatutako liburutegiak',
'plugin_necessite_lib' => 'plugin hunek @lib@ liburutegia beharesten du.',
'plugin_necessite_plugin' => 'Beharretsia : @plugin@ plugina @version@ bertsio minimoarekin.',
'plugin_necessite_spip' => 'SPIPen @version@ bertsio minimoa behar du.',
'plugin_source' => 'iturria:&nbsp;',
'plugin_titre_automatique' => 'Instalazio automatikoa',
'plugin_titre_automatique_ajouter' => 'Plugin batzu gehitu',
'plugin_titre_installation' => 'Installation du plugin @plugin@', # NEW
'plugin_zip_active' => 'Aktibatzeko, segitu',
'plugin_zip_adresse' => 'Hemen zehaz eazu deskargatu nahi duzun plugin  baten zip fitxategiaren helbidea, edo plugin zerrenda baten helbidea.',
'plugin_zip_adresse_champ' => 'pluginaren edo zerrendaren helbidea&nbsp;',
'plugin_zip_content' => 'Fitxategi hauek edukitzen ditu (@taille@),<br /><code>@rep@</code> directorioan instalatzeko prest.',
'plugin_zip_installe_finie' => '@zip@ fitxategia deskonprimitua eta instalatua izan da.',
'plugin_zip_installe_rep_finie' => '@zip@ fitxategia deskonprimitua izan da eta @rep@ direktorioan instalatua',
'plugin_zip_installer' => 'Orai instalatzen ahal duzu.',
'plugin_zip_telecharge' => '@zip@ fitxategia telekargatua izan da',
'plugins_actif_aucun' => 'Aucun plugin activ&#233;.', # NEW
'plugins_actif_un' => 'Un plugin activ&#233;.', # NEW
'plugins_actifs' => '@count@ plugin aktibatuak.',
'plugins_actifs_liste' => 'Plugins actifs', # NEW
'plugins_compte' => '@count@ plugin',
'plugins_disponible_un' => 'Un plugin disponible.', # NEW
'plugins_disponibles' => '@count@ plugin erabilgarriak',
'plugins_erreur' => 'Errorea pluginetan : @plugins@',
'plugins_liste' => 'Pluginen zerrenda',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Plugins r&eacute;cents.', # NEW
'plugins_vue_hierarchie' => 'Hierarkia',
'plugins_vue_liste' => 'Zerrenda',
'protocole_ldap' => 'Protokoloaren bersioa :',

// R
'repertoire_plugins' => 'Direktorioa&nbsp;:',

// S
'sans_heure' => 'ordurik gabe',
'sauvegarde_fusionner' => 'Une hunetako basea eta babeskopia batu',
'sauvegarde_fusionner_depublier' => 'Despublikatu batutako objetuak',
'sauvegarde_url_origine' => 'Beharrez, jatorrizko gunearen URLa :',
'statut_admin_restreint' => '(admin mugatua)',
'syndic_choix_moderation' => 'Zer egin gune huntarik etorriko diren hurrengi loturekin&nbsp;?',
'syndic_choix_oublier' => 'Sindikazio fitxategietan gehiago agertzen ez diren loturekin zer egin ?',
'syndic_choix_resume' => 'Gune zonbaitzuek artikuluen testu osoa hedatzen dute. eskugarri delarik sindikatu al nahi duzu&nbsp;:',
'syndic_lien_obsolete' => 'Zahartutako lotura',
'syndic_option_miroir' => 'automatikoki blokatu',
'syndic_option_oubli' => 'ezabatu (@mois@&nbsp;hilabeteren ondotik)',
'syndic_option_resume_non' => 'Artikuluen eduki osoa (HTML formatuan)',
'syndic_option_resume_oui' => 'bilduma sinple bat (testu formatuan)',
'syndic_options' => 'Sindikazio aukerak&nbsp;:',

// T
'taille_cache_image' => 'SPIPek automatikoki kalkulatzen dituen irudiek (dokumentuen binetak, grafikoki aurkeztutako tituluak, TeX formatuan diren matematika funtzioak...) @dir@ direktorioko @taille@-eko espazioa okupatzen dute.',
'taille_cache_infinie' => 'Gune honek ez du ezartzen CACHE direktorioaren tamaina-mugaketarik.',
'taille_cache_maxi' => 'SPIP-ek gune honen CACHE direktorioaren tamaina mugatzen saiatzen da @octets@ datura gutxi gora-behera.',
'taille_cache_octets' => 'Cachearen tamaina orain @octets@-koa da.',
'taille_cache_vide' => 'Cachea hutsik dago.',
'taille_repertoire_cache' => 'Cache direktorioaren tamaina',
'text_article_propose_publication' => 'Argitarapenerako proposatutako artikulua.',
'text_article_propose_publication_forum' => 'Ez beldurtu zure iritzia emateaz. Artikuluari foro bat lotua zaio (orri beherean).',
'texte_acces_ldap_anonyme_1' => 'LDAP zerbitzari batzuekez dute onartzen sarbide anonimorik. Kasu honetan hasierako sarbide-identifikatzaile batzehaztu behar da gero urtekarian informazioak bilatu ahal izateko. Hala ere, kasu gehienetan, hurrengo eremuak hutsik laga ahal izango dira.',
'texte_admin_effacer_01' => 'Manamendu honek datu-basearen edukiera osoa ezabatzendu, eta hemen konprimituriko idazlari eta administratzaile-sarbide guztiak. Hori egikarituondoren, SPIP-en berrinstalazioa hasi beharko duzu berriro base berri bat eta lehenadministratzaile-sarbide bat sortzeko.',
'texte_admin_effacer_stats' => 'Manu hunek gunearen bisiten estatistikei lotutako datu guziak ezabatzen ditu, artikuluen arrakasta barne.',
'texte_admin_tech_01' => 'Aukera honek basearen edukia ecrire/data direktorioan bilduko den fitxategi batean gordetzen uzten dizu.Halaber ez ahaztu IMG/direktorioaren osotasuna berreskuratzea, artikuluetan eta ataletan erabilitako irudiak eta dokumentuak dituena.',
'texte_admin_tech_02' => 'kontuz: babeskopia hau SPIP-en bertsio berdinarekin instalatutako gune batean bakarrik leheneratzen ahalko da. Horregatik ez da batez ere &laquo; basea hustu &raquo; behar, babeskopia berrinstalatzeko zain egonez eguneratze baten ondoren... <a href="@spipnet@">SPIPen dokumentazioa</a> kontsultatu.',
'texte_admin_tech_03' => 'Fitxategia modu konprimituan gordetzea, bere transferentzia mozteko zure ordenagailuan edo babeskopien zerbitzari batean, eta disko-lekua aurreztea aukera dezakezu.',
'texte_admin_tech_04' => 'Beste base betekin bat-egitearen helburuarekin, babeskopia atal huntara mugatzen ahal duzu :',
'texte_adresse_annuaire_1' => '(Zure urtekaria Web gune hau dagoen ordenagailu berdinean instalatzen bada, segur aski &laquo;localhost&raquo;-az ari gara.)',
'texte_ajout_auteur' => 'Hurrengo egilea artikulura gehitua izan da :',
'texte_annuaire_ldap_1' => '(LDAP) urtekari baterako sarbidea baduzu, erabiltzaileak automatikoki SPIP-en azpian inportatzeko erabili ahalduzu.',
'texte_article_statut' => 'Artikulu hau dago...',
'texte_article_virtuel' => 'Artikulu birtuala',
'texte_article_virtuel_reference' => 'Artikulu birtuala : zure SPIP gunean erreferentziatutako artikulua, baina beste URL batera birbideratua. Birbideratzea bertan behera uzteko, goiko URL-a ezabatu.',
'texte_aucun_resultat_auteur' => 'Emaitzarik ez "@cherche_auteur@"-rako',
'texte_auteur_messagerie' => 'Toki honekuneoro konektatuta dauden pertsonen zerrenda erakutsi ahal dizu, honela mezuakzuzenean trukatu ahal dituzu. Gainera, zerrendan ez agertzea erabaki dezakezu(besteontzat "ikustezina" zaude)',
'texte_auteur_messagerie_1' => 'Toki honek mezu-trukea eta eztabaida-foro pribatuen sorrera onartzen ditu tokiko parte-hartzaileen artean. Truke horietan parte ez hartzea erabaki ahal duzu zuk.',
'texte_auteurs' => 'AUTOREAK',
'texte_breves' => 'Laburrak argibide zehatzenargitaratze azkarra uzten duten artikulu txikiak dira.',
'texte_choix_base_1' => 'Baseaaukeratu',
'texte_choix_base_2' => 'MYSQL zerbitzariak data base ugari dauzka.',
'texte_choix_base_3' => 'Aukeratu hemen zure ostapen zuzkitzaileak eman dizuna:',
'texte_choix_table_prefix' => 'Mahaien aurrizkiak&nbsp;:',
'texte_commande_vider_tables_indexation' => 'Komando hau erabili SPIP-en integratuta dagoen bilaketa-tresnak erabilitako indexazio-taulak husteko. Honek disko-lekua irabazten utziko dizu.',
'texte_comment_lire_tableau' => 'Artikuluaren heina, onarpenaren araberako sailkapenean, marjinean dago adierazita ;
Artikuluaren onarpena (berak jasoko duen eguneroko bisiten kopuruaren estimazio bat oraingokontsulta-erritmoa mantentzen bada) eta hasieratik jasotako bisiten kopurua saguak izenburuaren gainetik pasatzen denean agertzen den argibidean erakusten dira.',
'texte_compacter_avertissement' => 'Kontuz, aaukera horiek ez aktibatu zure gunearen garapenaren denboran : konprimitutako elementuek irakurgarritasuna galtzen dute.',
'texte_compacter_script_css' => 'SPIPek javascript script-ak edo CSS estilo-orriak konprimitzen ahal ditu, fitxategi estatiko batzuetan grabatzeko ; horrek gunearen bistaratzea azeleratzen du.',
'texte_compresse_ou_non' => '(hau konprimitua izan ahal da edo ez)',
'texte_compresseur_page' => 'SPIPek gunearen bisitariei bidaltzen duen orri bakotxa automatikoki konprimitzen ahal du. konfigurazio hunek banda-zabaleraren optimizatzea baimentzen du (abiadura ttipiko konexio baten gibelean gunea zaluago da), baina zerbitzariari indar gehiago eskatzen du.',
'texte_compte_element' => '@count@ osagai',
'texte_compte_elements' => '@count@osagai',
'texte_config_groupe_mots_cles' => 'Gako-hitzen konfigurazio aurreratua aktibatu nahi duzu, adibidez talde bakoitzean hitz bakar bat hautatu ahal dela,talde bat garrantzitsua dela,... adieraziz?',
'texte_conflit_edition_correction' => 'Otoi, testoaren bi bertsio desberdinen arteko desberdinatsunak kontrola itzazu&nbsp;;edo zure aldaketak kopia itzazu, eta ondotik berriz hasi.',
'texte_connexion_mysql' => 'Zure ostapen zuzkitzaileak emandako informazioak kontsultatu :
zure ostapen zuzkitzaileak SQL jasaten badu, han aurkitu beharko zenituzke SQL zerbitzarirako konexio-kodeak.',
'texte_contenu_article' => '(Artikuluaren edukia hitz gutxitan)',
'texte_contenu_articles' => 'Zure tokiarendiseinuaren arabera, hemen erabili behar diren osagaiak aukera ditzakezu',
'texte_crash_base' => 'Baseak arazo bat baldin badauka, hemen konpontzen saiadaiteke',
'texte_creer_rubrique' => 'Artikulu bat idatzi aurretik, atal bat sortu behar duzu.',
'texte_date_creation_article' => ' Artikuluaren sortze data',
'texte_date_publication_anterieure' => 'Lehengo argitarapen data',
'texte_date_publication_anterieure_nonaffichee' => 'Aurreko argitarapen data ez erakutsi.',
'texte_date_publication_article' => 'ARGITARAPEN DATA:',
'texte_descriptif_petition' => 'Eskaeraren azalpena',
'texte_descriptif_rapide' => 'Deskribapen motza',
'texte_documents_joints' => 'Dokumentuak(fitxategi bulegotikak, irudiak, multimedia, etab.) artikuluetara eta/edo ataletara gehitzea baimendu ahal duzu. Gero fitxategi hauek artikuluan erreferientziatuak izaten ahalko dira, edo bananduta bistaratuak.', # MODIF
'texte_documents_joints_2' => 'Konfigurazio honek ez du galarazten irudien zuzeneko txertatzea artikuluetan.',
'texte_effacer_base' => 'Ezabatu SPIP datu-basea',
'texte_effacer_donnees_indexation' => 'Indexazio datak ezabatu',
'texte_effacer_statistiques' => 'Estatistikak ezabatu',
'texte_en_cours_validation' => 'Azpiko artikuluak eta berri laburrak argitarapenerako proposatuta daude.',
'texte_en_cours_validation_forum' => 'Ez izan zalantzarik zure iritzia emateko beraiei erantsitako foroei esker.',
'texte_enrichir_mise_a_jour' => 'Zure testuaren formatua aberastu dezakezu,"tipografia-lasterbideak" erabiliz',
'texte_fichier_authent' => 'SPIP-ek sortu behar al ditu.htpasswd et .htpasswd-admin fitxategi bereziak ecrire/data/ direktorioan
Fitxategi hauek egileei eta administrazaileei zure guneko inguru batzutan (adibidez, kanpoko estatistika-programa) sarbidea murrizteko balio ahal dute.
Ez baduzu baliagarritasunik, aukera hau bere balio lehenetsiari utzi ahal diozu (fitxategien sortzerik ez).', # MODIF
'texte_informations_personnelles_1' => 'Sistemak oraintokirako norberako sarrera sortuko du.',
'texte_informations_personnelles_2' => '(Oharra : berrinstalazio batez ari bagara, eta zure sarbidea beti funtzionatzen duela, ahal duzu',
'texte_introductif_article' => '(Artikuluaren sarrera.)',
'texte_jeu_caractere' => 'Aukera hau probetxugarria da zure guneak alfabeto erromatarreko (edo &laquo; mendebaldarrekoa &raquo;) alfabetodesberdinak eta bere eratorriak erakutsi behar baditu. Kasu honetan, komenigarria izango litzatekekonfigurazio lehenetsia aldatzea karaktere-joko egoki baterako ; kasu guztietan probak egiteagomendatzen dizugu irtenbide on bat aurkitzeko. Parametro hau aldatzen baduzu,ez ahaztu ondorioko gune publikoa egokitzen (#CHARSET marka).',
'texte_jeu_caractere_2' => 'Konfigurazio honek ez du atzeraeraginezko efekturik. Beraz,dagoeneko sartutako testuak gaizki bistaratu ahal dira konfigurazioaren aldaketa batenondorioz. Kasu guztietan, kalteri gabe aurreko konfiguraziora itzuli ahalizango zara.',
'texte_jeu_caractere_3' => 'Zure gunea karaktere-joko huntan instalatua da&nbsp;:',
'texte_jeu_caractere_4' => 'Si cela ne correspond pas &agrave; la r&eacute;alit&eacute; de vos donn&eacute;es (suite, par exemple, &agrave; une restauration de base de donn&eacute;es), ou si <em>vous d&eacute;marrez ce site</em> et souhaitez partir sur un autre jeu de caract&egrave;res, veuillez indiquer ce dernier ici&nbsp;:', # NEW
'texte_jeu_caractere_conversion' => 'Note&nbsp;: vous pouvez d&eacute;cider de convertir une fois pour toutes l\'ensemble des textes de votre site (articles, br&egrave;ves, forums, etc.) vers l\'alphabet <tt>utf-8</tt>, en vous rendant sur <a href="@url@">la page de conversion vers l\'utf-8</a>.', # NEW
'texte_lien_hypertexte' => 'Zure mezua Web-gunean argitaratutakoartikulu bati baldin badagokio, edo informazio gehiago dituen orrialde bati, jarri orainorriaren izenburua eta bere URL helbidea)',
'texte_liens_sites_syndiques' => 'sindikatutakoguneetako estekak a priori blokeatu ahal dira ; azpiko konfigurazioak sindikatutakoguneen konfigurazio lehenetsia adierazten du bere sorrera ondoren. Hala ere, gero estekabakoitza banan-banan desblokeatzea posible da, edo lekuz leku, gune batetik edo bestetik datozenestekak blokeatzeko aukera izatea.', # MODIF
'texte_login_ldap_1' => '(Hutsik laga sarbide anonimo baterako, edo bide osoan sartu, adibidez «uid=dupont, ou=users, dc=mon-domaine, dc=com ».)', # MODIF
'texte_login_precaution' => 'Kontuz ! Hau da orain konektatuta zaudenarekiko login-a. Inprimaki hau kontuz erabili...',
'texte_message_edit' => 'Adi Egon: tokiarenadministratzaileek mezu hau alda dezakete, eta erredaktore guztiek ikus dezakete.Iragarkiak erabili bakar bakarrik tokiaren bizitzaren gertakari garrantzitsuakiragartzeko.',
'texte_messagerie_agenda' => 'Une messagerie permet aux r&#233;dacteurs du site de communiquer entre eux directement dans l&#8217;espace priv&#233; du site. Elle est associ&#233;e &#224; un agenda.', # NEW
'texte_messages_publics' => 'Artikuluaren mezu publikoak',
'texte_mise_a_niveau_base_1' => 'SPIP-eko artxiboak berritu egin dituzu eta oraintokiaren data basea berritu egin behar duzu.',
'texte_modifier_article' => 'Artikuluaaldatu:',
'texte_moteur_recherche_active' => '<b>Bilaketa-tresna aktibatuta dago.</b>
 manamendu hau erabili, 
berrindexazio bizkor bati ekin nahi badiozu (adibidez babeskopiabat berreskuratu ondoren). Modu arruntean aldatutako dokumentuak (SPIP interfazetik)automatikoki berrindexatuak direla antzeman : 
beraz komando hau salbuespenezkomodurako bakarrik da probetxugarria.',
'texte_moteur_recherche_non_active' => 'Bilaketarako motorea ez dago aktibaturik.',
'texte_mots_cles' => 'Gako-hitzekinartikuluen artean lotura tematikoak egin ditzakezu, bere atalen barruko kokapena zeinden kontutan hartu gabe. Honela, zure tokiaren nabigazioa hobetu ahal duzu, edopropietate hauek ere erabili zure egituren barruan artikuluen itxura egokitzeko.',
'texte_mots_cles_dans_forum' => 'Gako-hitzen erabilera utzi nahi al duzu, bisitariektoki publikoaren foruetan aukeratu ahal izango dituztenak? (Adi egon: aukera haunahiko konplexua da zuzen erabiltzeko.)',
'texte_multilinguisme' => 'Hizkuntza batbaino gehiago erabili nahi baldin baduzu, nabigatze zailarekin, zure tokiarenantolakuntzaren arabera, artikuluentzat edota atalentzat hizkuntza aukeratzeko menu baterantsi ahal duzu.',
'texte_multilinguisme_trad' => 'Artikulu baten itzulpen desberdinenarteko lotura sistema bat ere aktiba dezakezu.',
'texte_non_compresse' => 'konpresiorikgabe (zure zerbitzariak ez du funtzionalitate hau jasaten)',
'texte_non_fonction_referencement' => 'Agian nahiago duzu funtzio automatiko hau ezerabili, eta zuk zeuk adierazi toki honi dagozkien osagaiak...',
'texte_nouveau_message' => 'Mezu berria',
'texte_nouveau_mot' => 'Hitz berria',
'texte_nouvelle_version_spip_1' => 'SPIPren bertsio berri bat instalatu duzu.',
'texte_nouvelle_version_spip_2' => 'Bertsioberri honek ohiko eguneratze osoago bat behar du. Guneko web arduraduna bazara,mesedez ecrire direktorioko inc_connect.php3 fitxategia ezabatu eta instalazioariberriro ekin zure konexio-parametroak eguneratzeko datu-basean.(NB. : zure konexio-parametroak ahaztu badituzu, inc_connect.php3 fitxategiagainbegiratu ezabatu aurretik...)', # MODIF
'texte_operation_echec' => 'Lehengo orriraitzuli, beste base bat aukeratu edo base berri bat sortu. Zure ostapen zuzkitzaileakemandako argibideak egiaztatu.',
'texte_plus_trois_car' => '3 karakter baino gehiago',
'texte_plusieurs_articles' => '"@cherche_auteur@" irizpiderako autore bat bainogehiago aurkitu egin dira:',
'texte_port_annuaire' => '(Besteak adierazi ezean,adierazitako balioa oro har zuzena da.)',
'texte_presente_plugin' => 'Cette page liste les plugins disponibles sur le site. Vous pouvez activer les plugins n&eacute;cessaires en cochant la case correspondante.', # NEW
'texte_proposer_publication' => 'Zure artikulua bukatuta egongo denean, zure argitarapena proposa dezakezu',
'texte_proxy' => 'Kasu batzuetan (Intranet, babestutako sareak...), beharrezkoa izan daiteke proxy HTTP baterabiltzea elkartutako tokietara heltzeko. 
Horrela baldin bada, jarraian ipini berehelbidea, http://proxy:8080 erapean. 
Orokorrean, aukera hau hutsik geratuko da.',
'texte_publication_articles_post_dates' => 'Zer nolako jarrera hartu behar du SPIP-ekberen argitaratze data oraindik heldu ez den data duten artikuluen aurrean?',
'texte_rappel_selection_champs' => '[Ez ahaztu eremu hau zuzenki hautatzea.]',
'texte_recalcul_page' => 'Orri bat baino ez baduzu berkalkulatu nahi,gunepublikoan dagoen "Berkalkulatu" botoia erabili.',
'texte_recapitiule_liste_documents' => 'Orri honek ataletan sartu dituzun dokumentu lista osoa erakusten du. Dokumentu bakoitzaren argibideak aldatzeko, erabili bere ataleko lotura.',
'texte_recuperer_base' => 'Datuen Basea konpondu',
'texte_reference_mais_redirige' => 'Zure tokianerreferentziatutako artikulua eta beste URL batengana berzuzenduta.',
'texte_referencement_automatique' => '<b>Leku bat automatikoki erreferentzia egitea</b>
Leku baten URL-a edo lekuaren "backend" artxiboaren helbidea, SPIP automatikoki argibideak (izenburua, azalpena....) berreskuratuko ditu.',
'texte_referencement_automatique_verifier' => 'Veuillez v&eacute;rifier les informations fournies par <tt>@url@</tt> avant d\'enregistrer.', # NEW
'texte_requetes_echouent' => 'SQL eskaera batzuk sistematikoki huts egiten dutenean eta badirudi ez dagoelaarrazoirik,posible da datu basea bera huts egiten ari dela. SQL-k gaitasun bat daukabere taulak konpontzeko istripu baten erruz hondatuak izan direnean. 
Hemenkonponketa hau egiten saia zaitezke; huts eginez gero, gorde emaitzaren kopia bat,posible baita huts egitearen aztarnak izatea... 
Arazoa berriro gertatzen baldin bada, zureostatu-sariaren hornitzailearekin kontaktuan jarri.', # MODIF
'texte_restaurer_base' => 'Ziurtasunkopiaren edukia berreskuratu',
'texte_restaurer_sauvegarde' => 'Aukera honekin lehenago egindako ziurtasun kopia bat berrezarri ahal duzu. Hau egin ahal izateko,ziurtasun kopia daukan fitxeroa ecrire/data/ direktorioan egon behar da. Kontuz ibilifuntzionalitate honekin: aldaketak edo galtze tenporalak atzeraezinak dira.',
'texte_sauvegarde' => 'Basean ziurtasun kopia bat sortu.',
'texte_sauvegarde_base' => 'Basean ziurtasun kopia bat sortu.',
'texte_sauvegarde_compressee' => 'Ziurtasun kopia ecrire/data/dump.xml konpresiorik gabeko artxibo batean egingo da.',
'texte_selection_langue_principale' => 'Jarraian tokiaren "hizkuntza nagusia" aukeradezakezu. Aukera honek ez du behartzen - zorionez!- artikuluak aukeratutakohizkuntzan idaztera, baina, besteak beste, gauza hauek zehaztu ahal dira:Besteak adierazi ezean, toki publikoan dataren formatua;Testuak errepikatzeko SPIP-ek erabili behar duen motor tipografikoaren natura;Toki publikoaren formularioetan erabilitako hizkuntza;Besteak adierazi ezean, gune pribatuan erakutsitako hizkuntza.',
'texte_signification' => 'Barra ilunek metatutako sarrerak irudikatzen dituzte(azpiatalen erabatekoa), barra argiek atal bakoitzaren bisita guztiak.',
'texte_sous_titre' => 'Azpititulua',
'texte_statistiques_visites' => '(barra ilunak : igandea / kurbailuna : ertainaren eboluzioa)',
'texte_statut_attente_validation' => 'Baliozkotasunaren zain',
'texte_statut_publies' => 'Argitaratuak',
'texte_statut_refuses' => 'Ezeztatuak',
'texte_suppression_fichiers' => 'Instrukzio hau erabili SPIP kache-andauden artxibo guztiak ezabatzeko. Honen bidez, besteak beste, aldaketa grafikoak edotokiaren egitura dezente aldatuz gero, orri guztiak berkalkula daitezke.',
'texte_sur_titre' => 'Aurreizenburua',
'texte_syndication' => 'Berritasunen zerrenda, Web-guneak halauzten duenean, automatikoki berreskuratzea posible da.
Horretarako, bilketa aktibatu behar duzu. Ostapen zuzkitzaile batzuk ez dute funtzionalitate hau aktibatzen; kasu horretan, ezin izango duzu zure gunearen edukiaren bilketa egin.',
'texte_table_ok' => ': Taula hau ondo dago.',
'texte_tables_indexation_vides' => 'Indexazio motorraren taulak hutsik daude.',
'texte_tentative_recuperation' => 'Konponketa saiakera.',
'texte_tenter_reparation' => 'Datu basearen konponketa saiatu.',
'texte_test_proxy' => 'Tokiaren URL-a hemen ipini "proxy" hau frogatzeko.',
'texte_titre_02' => 'Izenburua',
'texte_titre_obligatoire' => 'Izenburua [Derrigorrezkoa]',
'texte_travail_article' => '@nom_auteur_modif@ artikulu hau berridatzi egin duduela@date_diff@ minutu.',
'texte_travail_collaboratif' => 'Sarritan erredaktore batbaino gehiago artikulu berberan lan egiten dute, sistemak duela gutxi "irekiak" izandiren artikuluak erakutsi ahal du, aldi bereko aldaketak saihesteko. Aukera hau,kontrakoa egin ezean, desaktibatuta dago ezorduko abisu mezuak saihesteko.',
'texte_trop_resultats_auteurs' => '"@cherche_auteur@" bilaketarako emaitza gehiegi.Irizpideak zehaztu.',
'texte_type_urls' => 'Vous pouvez choisir ci-dessous le mode de calcul de l\'adresse des pages.', # NEW
'texte_type_urls_attention' => 'Attention ce r&eacute;glage ne fonctionnera que si le fichier @htaccess@ est correctement install&eacute; &agrave; la racine du site.', # NEW
'texte_unpack' => 'Azken bertsiotik telekargatua.',
'texte_utilisation_moteur_syndiques' => 'SPIP-en barneratutako bilaketa motorra erabiltzen duzunean, 
bilaketak tokietan eta sindikatutako artikuluetan bi era desberdinetan egin ditzakezu
Errazena artikuluen deskribapenetan eta izenburuetan bilatzean datza.
Bigarren era, askoz potenteagoa, SPIP-i erreferentziatutako tokien testuan bilatzen ereuzten dio. 
Toki bat erreferentziatzen baldin baduzu, orduan SPIP-ek tokiaren edukiaren barruan bilaketa egingo du.',
'texte_utilisation_moteur_syndiques_2' => 'Bide honekSPIP erreferentziatutako tokiak sarritan bisitatzera behartzen du, zure tokian abiadurabeherapen txikia eragiten duena.',
'texte_vide' => 'Hutsik',
'texte_vider_cache' => 'Kache-a hustu',
'titre_admin_effacer' => 'Mantenimendu teknikoa',
'titre_admin_tech' => 'Mantentze-lan teknikoa',
'titre_admin_vider' => 'Mantentze-lan teknikoa',
'titre_articles_syndiques' => 'Toki honetako elkartutako artikuluak',
'titre_breves' => 'Laburrak',
'titre_cadre_afficher_article' => 'Artikuluak erakutsi',
'titre_cadre_afficher_traductions' => 'Hizkuntza honetarako dauden itzulpenen egoeraerakutsi',
'titre_cadre_ajouter_auteur' => 'Idazle bat erantsi',
'titre_cadre_forum_administrateur' => 'Administrarien foroa',
'titre_cadre_forum_interne' => 'Barneko foroa',
'titre_cadre_interieur_rubrique' => 'Atalaren barnera',
'titre_cadre_numero_auteur' => 'IDAZLEA',
'titre_cadre_signature_obligatoire' => 'Izenpetzea [Derrigorrezkoa]',
'titre_compacter_script_css' => 'Compactage des scripts et CSS', # NEW
'titre_compresser_flux_http' => 'Compression du flux HTTP', # NEW
'titre_config_contenu_notifications' => 'Notifications', # NEW
'titre_config_contenu_prive' => 'Dans l&#8217;espace priv&#233;', # NEW
'titre_config_contenu_public' => 'Sur le site public', # NEW
'titre_config_fonctions' => 'Tokiaren konfigurazioa',
'titre_config_forums_prive' => 'Forums de l&#8217;espace priv&#233;', # NEW
'titre_config_groupe_mots_cles' => 'Gako-hitzen taldeen konfigurazioa',
'titre_configuration' => 'Tokiarenkonfigurazioa',
'titre_conflit_edition' => 'Conflit lors de l\'&#233;dition', # NEW
'titre_connexion_ldap' => 'Aukerak: zure LDAP konexioa',
'titre_dernier_article_syndique' => 'Azken artikulu elkartuak',
'titre_documents_joints' => 'Erantsitako dokumentuak',
'titre_evolution_visite' => 'Bisiten bilakaera',
'titre_forum_suivi' => 'Foruen kudeaketa',
'titre_gauche_mots_edit' => 'Hitza',
'titre_groupe_mots' => 'Hitzen taldea',
'titre_langue_article' => 'ARTIKULUKOHIZKUNTZA',
'titre_langue_breve' => 'LABURRAREN HIZKUNTZA',
'titre_langue_rubrique' => 'ATALAREN HIZKUNTZA',
'titre_langue_trad_article' => 'ARTIKULUKO HIZKUNTZA ETA ITZULPENAK',
'titre_les_articles' => 'Artikuluak',
'titre_messagerie_agenda' => 'Mezutegia eta agenda',
'titre_mots_cles_dans_forum' => 'Toki publikoko foroetan hitz gakoak',
'titre_mots_tous' => 'Gako-hitzak',
'titre_naviguer_dans_le_site' => 'Tokian ibili...',
'titre_nouveau_groupe' => 'Talde berria',
'titre_nouvelle_breve' => 'Labur berria',
'titre_nouvelle_rubrique' => 'Atal berria',
'titre_numero_rubrique' => 'ATALA:',
'titre_page_admin_effacer' => 'Mantenimendu teknikoa: basea ezabatu',
'titre_page_articles_edit' => '@titre@ Aldatu',
'titre_page_articles_page' => 'Artikuluak',
'titre_page_articles_tous' => 'Toki osoa',
'titre_page_auteurs' => 'Bisitari',
'titre_page_breves' => 'Berri laburrak',
'titre_page_breves_edit' => '« @titre@ » notalaburra aldatu',
'titre_page_calendrier' => 'Egutegia @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Tokiaren konfigurazioa',
'titre_page_config_fonctions' => 'Tokiaren konfigurazioa',
'titre_page_configuration' => 'Tokiaren konfigurazioa',
'titre_page_controle_petition' => 'Eskaeren jarraipena',
'titre_page_delete_all' => 'Itzuliezin eta erabateko ezabapena',
'titre_page_documents_liste' => 'Atalendokumentuak',
'titre_page_forum' => 'Administratzaileen eztabaida-lekua',
'titre_page_forum_envoi' => 'Mezu bat bidali',
'titre_page_forum_suivi' => 'Foruenjarraipena',
'titre_page_index' => 'Zure gune pribatua',
'titre_page_message_edit' => 'Mezu bat idatzi',
'titre_page_messagerie' => 'Zure mezularitza',
'titre_page_mots_tous' => 'Gako-hitzak',
'titre_page_recherche' => 'Bilaketaren emaitzak @recherche@',
'titre_page_sites_tous' => 'Erreferentziatutako tokiak',
'titre_page_statistiques' => 'Atalez atal estatistikak',
'titre_page_statistiques_messages_forum' => 'Foroko mezuak',
'titre_page_statistiques_referers' => 'Estatistikak (sartu direnloturak)',
'titre_page_statistiques_signatures_jour' => 'Nombre de signatures par jour', # NEW
'titre_page_statistiques_signatures_mois' => 'Nombre de signatures par mois', # NEW
'titre_page_statistiques_visites' => 'Bisiten estatistikak',
'titre_page_upgrade' => 'SPIPen gaurkotzea',
'titre_publication_articles_post_dates' => 'Geroko datarekinartikuluen argitarapena',
'titre_referencement_sites' => 'Toki erreferentziaketa etaelkarketa',
'titre_referencer_site' => 'Toki bat erreferentziatu',
'titre_rendez_vous' => 'AIPAMENAK:',
'titre_reparation' => 'Konponketa',
'titre_site_numero' => 'Tokia',
'titre_sites_proposes' => 'Proposatutako tokiak',
'titre_sites_references_rubrique' => 'Atal honetan erreferentziatutako tokiak',
'titre_sites_syndiques' => 'Elkartutako tokiak',
'titre_sites_tous' => 'Erreferentziatutako tokiak',
'titre_suivi_petition' => 'Eskaerenkudeaketa',
'titre_syndication' => 'Tokien elkarpena',
'titre_type_urls' => 'Type d\'adresses URL', # NEW
'tls_ldap' => 'Transport Layer Security :',
'tout_dossier_upload' => 'Karpeta osoa @upload@',
'trad_article_inexistant' => 'Zenbaki horrekin ez dago artikulurik',
'trad_article_traduction' => 'Artikulu honen bertsio guztiak:',
'trad_deja_traduit' => 'Errorea : Artikulu hau ezin da eskatutako zenbakiari lotu.',
'trad_delier' => 'Jada ez lotuartikulu hau bere itzulpenekin ',
'trad_lier' => 'Artikulu hau artikuluaren itzulpena da',
'trad_new' => 'Artikulu honen itzulpen berria idatzi',

// U
'upload_fichier_zip' => 'ZIP fitxategia',
'upload_fichier_zip_texte' => 'Instalatzea proposatzen den fitxategia Zip fitxategi bat da.',
'upload_fichier_zip_texte2' => 'Fitxategi hau izan ahal da:',
'upload_info_mode_document' => 'D&#233;poser cette image dans le portfolio', # NEW
'upload_info_mode_image' => 'Retirer cette image du portfolio', # NEW
'upload_limit' => 'Fitxategi hauhandiegia da zerbitzarirako; baimendutako gehienezko tamainia upload-ean@max@-koa da.',
'upload_zip_conserver' => 'Conserver l&#8217;archive apr&#232;s extraction', # NEW
'upload_zip_decompacter' => 'deskonprimituta eta gunean instalatutadaukan elementu bakoitza. Gunean instalatu egingo diren fitxategiak dira:',
'upload_zip_telquel' => 'Besterik gabe instalatuta, Zip fitxategi bezala;',
'upload_zip_titrer' => 'Titrer selon le nom des fichiers', # NEW
'utf8_convert_attendez' => 'Attendez quelques instants et rechargez cette page.', # NEW
'utf8_convert_avertissement' => 'Vous vous appr&ecirc;tez &agrave; convertir le contenu de votre base de donn&eacute;es (articles, br&egrave;ves, etc) du jeu de caract&egrave;res <b>@orig@</b> vers le jeu de caract&egrave;res <b>@charset@</b>.', # NEW
'utf8_convert_backup' => 'N\'oubliez pas de faire auparavant une sauvegarde compl&egrave;te de votre site. Vous devrez aussi v&eacute;rifier que vos squelettes et fichiers de langue sont compatibles @charset@.', # NEW
'utf8_convert_erreur_deja' => 'Votre site est d&eacute;j&agrave; en @charset@, inutile de le convertir...', # NEW
'utf8_convert_erreur_orig' => 'Erreur&nbsp;: le jeu de caract&egrave;res @charset@ n\'est pas support&eacute;.', # NEW
'utf8_convert_termine' => 'C\'est termin&eacute;&nbsp;!', # NEW
'utf8_convert_timeout' => '<b>Important&nbsp;:</b> en cas de <i>timeout</i> du serveur, veuillez recharger la page jusqu\'&agrave; ce qu\'elle indique &laquo;&nbsp;termin&eacute;&nbsp;&raquo;.', # NEW
'utf8_convert_verifier' => 'Vous devez maintenant aller vider le cache, et v&eacute;rifier que tout se passe bien sur les pages publiques du site. En cas de gros probl&egrave;me, une sauvegarde de vos donn&eacute;es a &eacute;t&eacute; r&eacute;alis&eacute;e (au format SQL) dans le r&eacute;pertoire @rep@.', # NEW
'utf8_convertir_votre_site' => 'Zure gunean utf-8-era konbertitu',

// V
'version' => 'Bertsioa&nbsp;:',
'version_deplace_rubrique' => '<b>&laquo;&nbsp;@from@&nbsp;&raquo;</b>-etik <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>-era mugitua.',
'version_initiale' => 'Hasierako bertsioioa'
);

?>
